OC.L10N.register(
    "spreed",
    {
    "a conversation" : "обсуждение",
    "(Duration %s)" : "(Продолжительность %s)",
    "You attended a call with {user1}" : "Вы участвовали в вызове с пользователем {user1}",
    "_%n guest_::_%n guests_" : ["%n гость","%n гостя","%n гостей","%n гостей"],
    "You attended a call with {user1} and {user2}" : "Вы участвовали в вызове с пользователями {user1} и {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Вы участвовали в вызове с пользователями {user1}, {user2} и {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Вы участвовали в вызове с пользователями {user1}, {user2}, {user3} и {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Вы участвовали в вызове с пользователями {user1}, {user2}, {user3}, {user4} и {user5}",
    "_%n other_::_%n others_" : ["ещё %n","ещё %n","ещё %n","ещё %n"],
    "{actor} invited you to {call}" : "{actor} приглашает вас в вызов «{call}»",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Вы были приглашены в <strong>обсуждение</strong> или в <strong>вызов</strong>",
    "Other activities" : "Другие события",
    "Talk" : "Конференции",
    "Guest" : "Гость",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## Добро пожаловать в приложение Конференции для Nextcloud!\nВ этом обсуждении приведена информация о новых функциях приложения.",
    "## New in Talk %s" : "## Новое в приложении «Конференции» версии %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Браузеры Microsoft Edge и Safari теперь могут быть использованы для участия в аудио- и видеовызовах",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Частные обсуждения теперь постоянны и не могут быть преобразованы в групповые обсуждения путём добавления новых участником. Также, когда один из участников покидает такое обсуждение, оно больше не удаляется автоматически. Только если оба участника покинули обсуждение, оно удаляется с сервера",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Теперь вы можете уведомлять всех участников, написав в чат \"@all\"",
    "- With the \"arrow-up\" key you can repost your last message" : "- Нажатием клавиши ↑ вы можете переслать своё последнее сообщение",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Теперь в приложении есть команды. Напишите \"/help\" в чат, чтобы увидеть, какие команды настроил ваш администратор",
    "- With projects you can create quick links between conversations, files and other items" : "- С помощью проектов вы можете создавать быстрые ссылки между обсуждениями, файлами и другими объектами",
    "- You can now mention guests in the chat" : "- Возможноcть упоминать гостей в сообщениях",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- У обсуждений теперь может быть лобби. Это позволит модераторам присоединиться к обсуждениям и вызовам раньше, чтобы подготовить встречу, в то время как пользователи и гости должны будут дождаться готовности",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Возможность непосредственного ответа на сообщения позволяет другим пользователям получать больше контекстной информации о содержимом сообщения",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Использование фильтра при поиске обсуждений и участников в существующих обсуждениях для упрощения поиска;",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- возможность добавлять к обсуждениям собственные группы пользователей при установленном приложении «Круги»;",
    "- Check out the new grid and call view" : " - Новый режим просмотра «Сетка» и новый экран вызова;",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : " - Возможность загружать и перетаскивать в чат файлы с используемого устройства;",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : " - Возможность просматривать опубликованные файлы непосредственно в чате с использованием приложения для просмотра;",
    "- You can now search for chats and messages in the unified search in the top bar" : " - Поиск обсуждений и сообщений из общей строки поиска, расположенной на верхней панели;",
    "- Spice up your messages with emojis from the emoji picker" : " - Панель выбора эмодзи;",
    "- You can now change your camera and microphone while being in a call" : " - Возможность сменить используемую камеру и микрофон во время вызова;",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : " - Возможность назначить обсуждениям контекст и описание для облегчения их поиска другими пользователями;",
    "- See a read status and send failed messages again" : " - Просмотр статуса прочтения сообщения и повторная отправка сообщений в случае сбоя при их доставке;",
    "- Raise your hand in a call with the R key" : " - Возможность «поднять руку» во время вызова (клавиша «R»);",
    "- Join the same conversation and call from multiple devices" : "- Возможность одновременно подключаться к обсуждениям и вызовам с различных устройств;",
    "- Send voice messages, share your location or contact details" : "- Передача голосовых сообщений, публикация местоположения и карточек контактов;",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Возможность добавить группу пользователей в обсуждение. Все новые члены группы будут автоматически добавлены в качестве участников;",
    "- A preview of your audio and video is shown before joining a call" : "- Перед подключением к звонку отображается предварительный просмотр аудио- и видео c камеры",
    "- You can now blur your background in the newly designed call view" : "- Теперь вы можете размыть фон в новом дизайне окна вызова",
    "- Moderators can now assign general and individual permissions to participants" : "- Модераторы теперь могут назначать общие и индивидуальные разрешения для участников",
    "- You can now react to chat messages" : "- Теперь вы можете реагировать на сообщения в чате",
    "- In the sidebar you can now find an overview of the latest shared items" : "- На боковой панели теперь можно найти обзор последних общих элементов",
    "- Use a poll to collect the opinions of others or settle on a date" : "- Используйте опрос, чтобы узнать мнение других людей или договориться о дате",
    "- Configure an expiration time for chat messages" : "- Настройка срока жизни сообщений чата",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- Начинайте вызовы, не уведомляя других участников большого обсуждения. Вы можете отправить индивидуальные уведомления о вызове после его начала.",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- Отправлять сообщения чата без уведомления пользователей, если они не являются срочными",
    "- Emojis can now be autocompleted by typing a \":\"" : "- Эмодзи теперь можно заполнять автоматически, набрав «:»",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- Свяжите различные элементы, используя новый смарт-выборщик, набрав «/»",
    "- Moderators can now create breakout rooms (requires the High-performance backend)" : "- Модераторы теперь могут создавать комнаты обсуждения (требуется Высокопроизводительный сервер).",
    "- Calls can now be recorded (requires the High-performance backend)" : "- Вызовы теперь могут быть записаны (требуется Высокопроизводительный сервер)",
    "- Conversations can now have an avatar or emoji as icon" : "- Разговоры теперь могут иметь аватар или эмодзи в качестве значка",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "- В дополнение к размытому фону в видеовызовах теперь доступны виртуальные фоны",
    "- Reactions are now available during calls" : "- Реакции теперь доступны во время вызовов",
    "- Typing indicators show which users are currently typing a message" : "- Индикаторы набора показывают, какие пользователи в данный момент набирают сообщение",
    "- Groups can now be mentioned in chats" : "- Группы теперь можно упоминать в сообщениях чата",
    "- Call recordings are automatically transcribed if a transcription provider app is registered" : "- Записи вызовов автоматически расшифровываются, если зарегистрировано приложение - транскриптор",
    "- Chat messages can be translated if a translation provider app is registered" : "- Сообщения чата могут быть переведены, если зарегистрировано приложение - переводчик",
    "- **Markdown** can now be used in _chat_ messages" : "- **Markdown** разметка теперь доступна в сообщениях _чата_",
    "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/" : "- Теперь доступны веб-хуки для внедрения ботов. Дополнительную информацию смотрите в документации https://nextcloud-talk.readthedocs.io/en/latest/bot-list/",
    "- Set a reminder on a chat message to be notified later again" : "- Установите напоминание на сообщение чата, чтобы позже снова получить уведомление",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- Используйте **Личные заметки**, чтобы делать заметки и делиться информацией между вашими устройствами",
    "- Captions allow to send a message with a file at the same time" : "- Подписи позволяют отправить текстовое сообщение одновременно с файлом",
    "- Video of the speaker is now visible while sharing the screen and call reactions are animated" : "- Видео выступающего теперь отображается при презентации экрана, и реакции в вызове анимированы",
    "- Messages can now be edited by logged-in authors and moderators for 6 hours" : "- Сообщения теперь могут быть изменены авторами и модераторами в течение 6 часов",
    "- Unsent message drafts are now saved in your browser" : "- Черновики неотправленных сообщений теперь сохраняются в вашем браузере.",
    "- Text chatting can now be done in a federated way with other Talk servers" : "- Обмен сообщениями теперь может происходит в федеративных обсуждениях с другими серверами Talk",
    "- Moderators can now ban accounts and guests to prevent them from rejoining a conversation" : "- Модераторы теперь могут блокировать аккаунты и гостей, чтобы они не могли снова присоединиться к обсуждению",
    "- Upcoming calls from linked calendar events and out-of-office replacements are now shown in conversations" : "- Предстоящие вызовы из связанных с календарем событий и замены вне офиса теперь отображаются в обсуждениях",
    "- Calls can now be done in a federated way with other Talk servers (requires the High-performance backend)" : "- Вызовы теперь можно совершать через федерации с другими Talk серверами (требуется Высокопроизводительный сервер)",
    "- Introducing the Nextcloud Talk desktop client for Windows, macOS and Linux: %s" : "- «Nextcloud Talk» клиент для настольных ПК доступен для Windows, macOS и Linux: %s",
    "- Summarize call recordings and unread messages in chats with the Nextcloud Assistant" : "- Резюме записанных вызовов и непрочитанных сообщений в чате с помощью «Nextcloud Assistant»",
    "- Improved meetings with recognizing guests invited via their email address, import of participant lists, drafts for polls and downloading call participant lists" : "Улучшенные встречи: распознавание гостей, приглашенных через адрес эл. почты, импорт списка участников в обсуждение, экспорт списка участников вызова и черновики опросов.",
    "- Archive conversations to stay focused" : "- Возможность архивировать обсуждения",
    "- Schedule a meeting into your calendar from within a conversation" : "- Назначение встречи в своём календаре прямо из обсуждения",
    "- Search for messages of the current conversation directly in the right sidebar" : "-  Поиск по сообщениям в текущем обсуждении через боковую панель",
    "- See more conversations on a first glance with the new compact list (enable in the Talk settings)" : "Обзор большего числа обсуждений с помощью нового компактного списка (доступно в настройках приложения)",
    "- Meeting conversations now sync the title and description from the calendar and are hidden with a search filter until they are close to the start" : "Обсуждения - встречи теперь синхронизируют название и описание из календаря и скрыты с помощью фильтра поиска до тех пор, пока они не будут близки ко времени начала",
    "- Mark conversations as sensitive in the notification settings, to hide the message content from the conversation list and notifications" : "- Отметьте обсуждения как конфиденциальные в настройках уведомлений, чтобы скрыть содержимое сообщений из списка обсуждений и уведомлений",
    "- To receive push notifications during \"Do not disturb\", mark conversations as important" : "- Чтобы получать уведомления в режиме «Не беспокоить», отмечайте обсуждения как важные",
    "- Add other participants to a one-to-one call to create a new group call on the fly" : "- Добавляйте других участников к частному вызову, чтобы создать новый групповой вызов на лету",
    "- Use threads to keep your chat and discussions organized" : "- Используйте темы для организации чата и дискуссий",
    "- Live transcriptions now available during the call (requires the live-transcription ExApp and the High-performance backend)" : "- Транскрипция вызовов в реальном времени теперь доступна (требуется ExApp для транскрипций в реальном времени и Высокопроизводительный сервер)",
    "- Moderators can now pin messages so they are kept at the top" : "- Теперь модераторы могут закреплять сообщения, чтобы они оставались вверху",
    "- Schedule a message to send it at a later time" : "- Запланировать сообщение к отправке в указанное время",
    "_All %n participant_::_All %n participants_" : ["%n участник","Все %n участника","Все %n участников","Все %n участников"],
    "Talk updates ✅" : "Обновления приложения «Конференции» ✅",
    "Reaction deleted by author" : "Реакция удалена автором",
    "{actor} created the conversation" : "{actor} создал(а) обсуждение",
    "You created the conversation" : "Вы создали обсуждение",
    "System created the conversation" : "Обсуждение создано системой автоматически",
    "An administrator created the conversation" : "Администратор создал обсуждение",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} переименовал(а) обсуждение «%1$s» в «%2$s»",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Вы переименовали обсуждение «%1$s» в «%2$s»",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Администратор переименовал обсуждение «%1$s» в «%2$s»",
    "{actor} set the description" : "{actor} установил(а) описание",
    "You set the description" : "Вы установили описание",
    "An administrator set the description" : "Администратор установил описание",
    "{actor} removed the description" : "{actor} удалил(a) описание",
    "You removed the description" : "Вы удалили описание",
    "An administrator removed the description" : "Администратор удалил описание",
    "You started a silent call" : "Вы начали тихий вызов",
    "Outgoing silent call" : "Исходящий тихий вызов",
    "{actor} started a silent call" : "{actor} начал(а) тихий вызов",
    "Incoming silent call" : "Входящий тихий вызов",
    "You started a call" : "Вы начали вызов",
    "Outgoing call" : "Исходящий вызов",
    "{actor} started a call" : "{actor} начал(а) вызов",
    "Incoming call" : "Входящий вызов",
    "{actor} joined the call" : "{actor} присоединился(лась) к вызову",
    "You joined the call" : "Вы присоединились к вызову",
    "{actor} left the call" : "{actor} покинул(а) вызов",
    "You left the call" : "Вы покинули вызов",
    "{actor} unlocked the conversation" : "{actor} разблокировал(а) обсуждение",
    "You unlocked the conversation" : "Вы разблокировали обсуждение",
    "An administrator unlocked the conversation" : "Администратор разблокировал обсуждение",
    "{actor} locked the conversation" : "{actor} заблокировал(а) обсуждение",
    "You locked the conversation" : "Вы заблокировали обсуждение",
    "An administrator locked the conversation" : "Администратор заблокировал обсуждение",
    "{actor} limited the conversation to the current participants" : "{actor} ограничил(а) доступ к обсуждению только текущими участниками",
    "You limited the conversation to the current participants" : "Вы ограничили доступ к обсуждению только текущими участниками",
    "An administrator limited the conversation to the current participants" : "Администратор ограничил доступ к обсуждению только текущими участниками",
    "{actor} opened the conversation to registered users" : "{actor} открыл(а) доступ к обсуждению для зарегистрированных пользователей",
    "You opened the conversation to registered users" : "Вы открыли доступ к обсуждению для зарегистрированных пользователей",
    "An administrator opened the conversation to registered users" : "Администратор открыл доступ к обсуждению для зарегистрированных пользователей",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "{actor} открыл обсуждение для зарегистрированных пользователей и пользователей, созданных через приложение «Гости»",
    "You opened the conversation to registered users and users created with the Guests app" : "Вы открыли обсуждение для зарегистрированных пользователей и пользователей, созданных через приложение «Гости»",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "Администратор открыл обсуждение для зарегистрированных пользователей и пользователей, созданных через приложение «Гости»",
    "The conversation is now open to everyone" : "Обсуждение теперь открыто для всех",
    "{actor} opened the conversation to everyone" : "{actor} открыл(а) обсуждение для всех",
    "You opened the conversation to everyone" : "Вы открыли обсуждение для всех",
    "{actor} restricted the conversation to moderators" : "{actor} ограничил(а) доступ к обсуждению только для модераторов",
    "You restricted the conversation to moderators" : "Вы ограничили доступ к обсуждению только для модераторов",
    "{actor} started breakout rooms" : "{actor} запустил(а) комнаты обсуждения",
    "You started breakout rooms" : "Вы запустили комнаты обсуждения",
    "{actor} stopped breakout rooms" : "{actor} остановил(а) комнаты обсуждения",
    "You stopped breakout rooms" : "Вы остановили комнаты обсуждения",
    "{actor} allowed guests" : "{actor} разрешил(а) участие гостей",
    "You allowed guests" : "Вы разрешили участие гостей",
    "An administrator allowed guests" : "Администратор разрешил участие гостей",
    "{actor} disallowed guests" : "{actor} запретил(а) участие гостей",
    "You disallowed guests" : "Вы запретили участие гостей",
    "An administrator disallowed guests" : "Администратор запретил участие гостей",
    "{actor} set a password" : "{actor} установил(а) пароль",
    "You set a password" : "Вы установили пароль",
    "An administrator set a password" : "Администратор установил пароль",
    "{actor} removed the password" : "{actor} удалил(а) пароль",
    "You removed the password" : "Вы удалили пароль",
    "An administrator removed the password" : "Администратор удалил пароль",
    "{actor} added {user}" : "{actor} добавил(а) пользователя {user}",
    "You joined the conversation" : "Вы присоединились к обсуждению",
    "{actor} joined the conversation" : "{actor} присоединился(лась) к обсуждению",
    "You added {user}" : "Вы добавили {user}",
    "{actor} added you" : "{actor} добавил(а) Вас",
    "An administrator added you" : "Администратор добавил вас",
    "An administrator added {user}" : "Администратор добавил {user} ",
    "You left the conversation" : "Вы покинули обсуждение",
    "{actor} left the conversation" : "{actor} покинул(а) обсуждение",
    "{actor} removed {user}" : "{actor} исключил(а) {user}",
    "You removed {user}" : "Вы исключили {user}",
    "{actor} removed you" : "{actor} исключил(а) Вас",
    "An administrator removed you" : "Администратор исключил вас",
    "An administrator removed {user}" : "Администратор исключил {user} ",
    "{actor} invited {federated_user}" : "{actor} пригласил(а) {federated_user}",
    "You invited {federated_user}" : "Вы пригласили {federated_user}",
    "You accepted the invitation" : "Вы приняли приглашение",
    "{actor} invited you" : "{actor} пригласил(а) Вас",
    "An administrator invited you" : "Администратор пригласил Вас",
    "An administrator invited {federated_user}" : "Администратор пригласил {federated_user} ",
    "{federated_user} accepted the invitation" : "{federated_user} принял(а) приглашение",
    "{actor} removed {federated_user}" : "{actor} исключил(а) {federated_user}",
    "You removed {federated_user}" : "Вы исключили {federated_user}",
    "You declined the invitation" : "Вы отклонили приглашение",
    "An administrator removed {federated_user}" : "Администратор исключил {federated_user} ",
    "{federated_user} declined the invitation" : "{federated_user} отклонил(а) приглашение",
    "{actor} added group {group}" : "{actor} добавил(а) группу {group}",
    "You added group {group}" : "Вы добавили группу {group}",
    "An administrator added group {group}" : "Администратор добавил группу {group}",
    "{actor} removed group {group}" : "{actor} исключил(а) группу {group}",
    "You removed group {group}" : "Вы исключили группу {group}",
    "An administrator removed group {group}" : "Администратор исключил группу {group}",
    "{actor} added team {circle}" : "{actor} добавил(а) команду {circle}",
    "You added team {circle}" : "Вы добавили команду {circle}",
    "An administrator added team {circle}" : "Администратор добавил команду {circle}",
    "{actor} removed team {circle}" : "{actor} исключил(а) команду {circle}",
    "You removed team {circle}" : "Вы исключили команду {circle}",
    "An administrator removed team {circle}" : "Администратор исключил команду {circle}",
    "{actor} added {phone}" : "{actor} добавил(а) {phone}",
    "You added {phone}" : "Вы добавили {phone}",
    "An administrator added {phone}" : "Администратор добавил {phone} ",
    "{actor} removed {phone}" : "{actor} исключил(а) {phone}",
    "You removed {phone}" : "Вы исключили {phone}",
    "An administrator removed {phone}" : "Администратор исключил {phone}",
    "{actor} promoted {user} to moderator" : "{actor} назначил(а) пользователя {user} модератором",
    "You promoted {user} to moderator" : "Вы назначили {user} модератором",
    "{actor} promoted you to moderator" : "{actor} назначил(а) Вас модератором",
    "An administrator promoted you to moderator" : "Администратор назначил Вас модератором",
    "An administrator promoted {user} to moderator" : "Администратор назначил {user} модератором",
    "{actor} demoted {user} from moderator" : "{actor} исключил(а) пользователя {user} из модераторов",
    "You demoted {user} from moderator" : "Вы исключили {user} из модераторов",
    "{actor} demoted you from moderator" : "{actor} исключил(а) Вас из модераторов",
    "An administrator demoted you from moderator" : "Администратор исключил Вас из модераторов",
    "An administrator demoted {user} from moderator" : "Администратор исключил {user} из модераторов",
    "{actor} shared a file which is no longer available" : "{actor} предоставил(а) общий доступ к файлу, который более не доступен",
    "You shared a file which is no longer available" : "Вы поделились файлом, который более не доступен",
    "File shares are currently not supported in federated conversations" : "Обмен файлами на данный момент не поддерживается федеративными обсуждениями",
    "The shared location is malformed" : "Неправильно указано общее местоположение ",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} настроил(а) Matterbridge для обмена сообщениями с другими чатами",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Вы настроили Matterbridge для обмена сообщениями с другими чатами",
    "{actor} created thread {title}" : "{actor} создал(а) тему {title}",
    "You created thread {title}" : "Вы создали тему {title}",
    "{actor} renamed thread {title}" : "{actor} переименовал тему {title}",
    "You renamed thread {title}" : "Вы переименовали тему {title}",
    "{actor} updated the Matterbridge configuration" : "{actor} изменил(а) конфигурацию системы обмена сообщениями Matterbridge",
    "You updated the Matterbridge configuration" : "Вы изменили конфигурацию системы обмена сообщениями Matterbridge",
    "{actor} removed the Matterbridge configuration" : "{actor} удалил(а) конфигурацию системы обмена сообщениями Matterbridge",
    "You removed the Matterbridge configuration" : "Вы удалили конфигурацию системы обмена сообщениями Matterbridge",
    "{actor} started Matterbridge" : "{actor} запустил(а) систему обмена сообщениями Matterbridge",
    "You started Matterbridge" : "Вы запустили систему обмена сообщениями Matterbridge",
    "{actor} stopped Matterbridge" : "{actor} остановил(а) систему обмена сообщениями Matterbridge",
    "You stopped Matterbridge" : "Вы остановили систему обмена сообщениями Matterbridge",
    "{actor} deleted a message" : "{actor} удалил(а) сообщение",
    "You deleted a message" : "Вы удалили сообщение",
    "{actor} edited a message" : "{actor} изменил(а) сообщение",
    "You edited a message" : "Вы изменили сообщение",
    "{actor} pinned a message" : "{actor} закрепил(а) сообщение",
    "You pinned a message" : "Вы закрепили сообщение",
    "{actor} unpinned a message" : "{actor} открепил(а) сообщение",
    "Message was automatically unpinned" : "Сообщение было автоматически откреплено",
    "You unpinned a message" : "Вы открепили сообщение",
    "{actor} deleted a reaction" : "{actor} удалил(а) реакцию",
    "You deleted a reaction" : "Вы удалили реакцию",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["Вы установили срок жизни сообщений в %n неделю","Вы установили срок жизни сообщений в %n недели","Вы установили срок жизни сообщений в %n недель","Вы установили срок жизни сообщений в %n недель"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["Вы установили срок жизни сообщений в %n день","Вы установили срок жизни сообщений в %n дня","Вы установили срок жизни сообщений в %n дней","Вы установили срок жизни сообщений в %n дней"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["Вы установили срок жизни сообщений в %n час","Вы установили срок жизни сообщений в %n часа","Вы установили срок жизни сообщений в %n часов","Вы установили срок жизни сообщений в %n часов"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["Вы установили срок жизни сообщений в %n минуту","Вы установили срок жизни сообщений в %n минуты","Вы установили срок жизни сообщений в %n минут","Вы установили срок жизни сообщений в %n минут"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor} установил(а) срок жизни сообщений в %n неделю","{actor} установил(а) срок жизни сообщений в %n недели","{actor} установил(а) срок жизни сообщений в %n недель","{actor} установил(а) срок жизни сообщений в %n недель"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor} установил(а) срок жизни сообщений в %n день","{actor} установил(а) срок жизни сообщений в %n дня","{actor} установил(а) срок жизни сообщений в %n дней","{actor} установил(а) срок жизни сообщений в %n дней"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor} установил(а) срок жизни сообщений в %n час","{actor} установил(а) срок жизни сообщений в %n часа","{actor} установил(а) срок жизни сообщений в %n часов","{actor} установил(а) срок жизни сообщений в %n часов"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor} установил(а) срок жизни сообщений в %n минуту","{actor} установил(а) срок жизни сообщений в %n минуты","{actor} установил(а) срок жизни сообщений в %n минут","{actor} установил(а) срок жизни сообщений в %n минут"],
    "{actor} disabled message expiration" : "{actor} отключил срок жизни сообщений",
    "You disabled message expiration" : "Вы отключили срок жизни сообщений",
    "{actor} cleared the history of the conversation" : "{actor} удалил(а) историю обсуждения",
    "You cleared the history of the conversation" : "Вы очистили историю обсуждения",
    "{actor} set the conversation picture" : "{actor} установил изображение обсуждения",
    "You set the conversation picture" : "Вы установили изображение обсуждения",
    "{actor} removed the conversation picture" : "{actor} удалил изображение обсуждения",
    "You removed the conversation picture" : "Вы удалили изображение обсуждения",
    "{actor} ended the poll {poll}" : "{actor} завершил(а) опрос {poll}",
    "You ended the poll {poll}" : "Вы завершили опрос {poll}",
    "{actor} started the video recording" : "{actor} начал(а) запись видео",
    "You started the video recording" : "Вы начали запись видео",
    "{actor} stopped the video recording" : "{actor} остановил запись видео",
    "You stopped the video recording" : "Вы остановили запись видео",
    "{actor} started the audio recording" : "{actor} начал(а) запись аудио",
    "You started the audio recording" : "Вы начали запись аудио",
    "{actor} stopped the audio recording" : "{actor} остановил запись аудио",
    "You stopped the audio recording" : "Вы остановили запись аудио",
    "The recording failed" : "Ошибка записи",
    "Someone voted on the poll {poll}" : "Кто-то проголосовал в опросе {poll}",
    "Message deleted by author" : "Сообщение удалено автором",
    "Message deleted by {actor}" : "Сообщение удалено {actor}",
    "Message deleted by you" : "Сообщение удалено Вами",
    "Deleted user" : "Удалённый пользователь",
    "Unknown number" : "Неизвестный номер",
    "Administration" : "Администрирование",
    "System" : "Системный",
    "%s (guest)" : "%s (гость)",
    "Missed call" : "Пропущенный вызов",
    "Unanswered call" : "Вызов без ответа",
    "Call ended (Duration {duration})" : "Вызов завершён (Продолжительность {duration})",
    "Call was ended, as it reached the maximum call duration (Duration {duration})" : "Вызов завершён по достижении максимальной продолжительности (Продолжительность {duration})",
    "{actor} ended the call (Duration {duration})" : "{actor} завершил(а) вызов (Продолжительность {duration})",
    "_Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})_::_Call with %n guests was ended, as it reached the maximum call duration (Duration {duration})_" : ["Вызов с %n гостем завершён по достижении максимальной продолжительности (Продолжительность {duration})","Вызов с %n гостями завершён по достижении максимальной продолжительности (Продолжительность {duration})","Вызов с %n гостями завершён по достижении максимальной продолжительности (Продолжительность {duration})","Вызов с %n гостями завершён по достижении максимальной продолжительности (Продолжительность {duration})"],
    "_Call with %n guest ended (Duration {duration})_::_Call with %n guests ended (Duration {duration})_" : ["Вызов с %n гостем завершён (Продолжительность {duration})","Вызов с %n гостями завершён (Продолжительность {duration})","Вызов с %n гостями завершён (Продолжительность {duration})","Вызов с %n гостями завершён (Продолжительность {duration})"],
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} завершил(а) вызов с %n гостем (Продолжительность {duration})","{actor} завершил(а) вызов с %n гостями (Продолжительность {duration})","{actor} завершил(а) вызов с %n гостями (Продолжительность {duration})","{actor} завершил(а) вызов с %n гостями (Продолжительность {duration})"],
    "Call with {user1} was ended, as it reached the maximum call duration (Duration {duration})" : "Вызов с {user1} завершён по достижении максимальной продолжительности (Продолжительность {duration})",
    "Call with {user1} ended (Duration {duration})" : "Вызов с {user1} завершён (Продолжительность {duration})",
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} завершил(а) вызов с {user1} (Продолжительность {duration})",
    "Call with {user1} and {user2} was ended, as it reached the maximum call duration (Duration {duration})" : "Вызов с {user1} и {user2} завершён по достижении максимальной продолжительности (Продолжительность {duration})",
    "Call with {user1} and {user2} ended (Duration {duration})" : "Вызов с {user1} и {user2} завершён (Продолжительность {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} завершил(а) вызов с {user1} и {user2} (Продолжительность {duration})",
    "Call with {user1}, {user2} and {user3} was ended, as it reached the maximum call duration (Duration {duration})" : "Вызов с {user1}, {user2} и {user3} завершён по достижении максимальной продолжительности (Продолжительность {duration})",
    "Call with {user1}, {user2} and {user3} ended (Duration {duration})" : "Вызов с {user1}, {user2} и {user3} завершён (Продолжительность {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} завершил(а) вызов с {user1}, {user2} и {user3} (Продолжительность {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} was ended, as it reached the maximum call duration (Duration {duration})" : "Вызов с {user1}, {user2}, {user3} и {user4} завершён по достижении максимальной продолжительности (Продолжительность {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} ended (Duration {duration})" : "Вызов с {user1}, {user2}, {user3} и {user4} завершён (Продолжительность {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} завершил(а) вызов с {user1}, {user2}, {user3} и {user4} (Продолжительность {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} was ended, as it reached the maximum call duration (Duration {duration})" : "Вызов с {user1}, {user2}, {user3}, {user4} и {user5} завершён по достижении максимальной продолжительности (Продолжительность {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} ended (Duration {duration})" : "Вызов с {user1}, {user2}, {user3}, {user4} и {user5} завершён (Продолжительность {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} завершил(а) вызов с {user1}, {user2}, {user3}, {user4} и {user5} (Продолжительность {duration})",
    "Message of {user} in {conversation}" : "Сообщение от {user} в {conversation}",
    "Message of {user}" : "Сообщение от {user}",
    "Message of a deleted user in {conversation}" : "Сообщение от удалённого пользователя в {conversation}",
    "Talk conversations" : "Обсуждения",
    "Talk to %s" : "Начать обсуждение с %s",
    "An error occurred. Please contact your administrator." : "Произошла ошибка. Пожалуйста, свяжитесь с администратором.",
    "App disabled" : "Приложение отключено",
    "Conversation subfolders are disabled" : "Подпапки для обсуждений отключены",
    "Storage quota exceeded" : "Превышена квота хранилища",
    "Could not prepare conversation folder" : "Не удалось подготовить папку для обсуждения",
    "File not found" : "Файл не найден",
    "Path must point to a file" : "Путь должен указывать на файл",
    "File is not inside the conversation draft folder for this room" : "Файл не найден в черновой папке для этого обсуждения",
    "File is not shared, or shared but not with the user" : "Файл не имеет общего доступа, либо имеет, но не с пользователем",
    "No account available to delete." : "Отсутствуют учётные записи, которые возможно удалить.",
    "Poll" : "Опрос",
    "Password needs to be set" : "Необходимо установить пароль",
    "Uploading the file failed" : "Не удалось загрузить файл",
    "No image file provided" : "Файл изображения не указан",
    "File is too big" : "Файл слишком большой",
    "Invalid file provided" : "Указан неправильный файл",
    "Invalid image" : "Некорректное изображение",
    "Unknown filetype" : "Неизвестный тип файла",
    "Talk mentions" : "Упоминания в обсуждениях",
    "More conversations" : "Больше обсуждений",
    "Say hi to your friends and colleagues!" : "Поприветствуйте своих друзей и коллег.",
    "No unread mentions" : "Нет ни одного непрочитанного упоминания",
    "Call in progress" : "Выполняется вызов",
    "You were mentioned" : "Вы были упомянуты",
    "Write to conversation" : "Написать в обсуждение",
    "Writes event information into a conversation of your choice" : "Выводит в обсуждение выбранную информацию о событии",
    "Missing email field in header line" : "Отсутствует поле «email» в строке заголовка",
    "Following lines are invalid: %s" : "Следующие строки некорректны: %s",
    "%1$s invited you to conversation \"%2$s\"." : "%1$s пригласил вас в обсуждение «%2$s».",
    "You were invited to conversation \"%s\"." : "Вы были приглашены в обсуждение «%s».",
    "Conversation invitation" : "Приглашение на участие в обсуждении",
    "Scheduled time" : "Запланированное время",
    "Description" : "Описание",
    "You can also dial-in via phone with the following details" : "Вы можете позвонить в конференцию, использую приведённые ниже данные",
    "Dial-in information" : "Сведения для звонка",
    "Meeting ID" : "Идентификатор встречи (ID)",
    "Your PIN" : "Ваш ПИН",
    "Click the button below to join the lobby now." : "Нажмите кнопку ниже, чтобы присоединиться к лобби прямо сейчас.",
    "Click the link below to join the lobby now." : "Нажмите ссылку ниже, чтобы присоединиться к лобби прямо сейчас.",
    "Join lobby for \"%s\"" : "Присоединиться к лобби в «%s»",
    "Click the button below to join the conversation now." : "Нажмите кнопку ниже, чтобы присоединиться к обсуждению прямо сейчас.",
    "Click the link below to join the conversation now." : "Нажмите ссылку ниже, чтобы присоединиться к обсуждению прямо сейчас.",
    "Join \"%s\"" : "Присоединиться к «%s»",
    "Meeting" : "Встреча",
    "Password request: %s" : "Запрос пароля: %s",
    "Private conversation" : "Частное обсуждение",
    "Deleted user (%s)" : "Удалённый пользователь (%s)",
    "Failed to upload call recording" : "Не удалось загрузить запись вызова",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "Серверу записи не удалось загрузить запись вызова {call}. Пожалуйста, обратитесь к администрации.",
    "Share to chat" : "Поделиться в чате",
    "Dismiss notification" : "Скрыть уведомление",
    "Call recording now available" : "Доступна запись вызовов",
    "The recording for the call in {call} was uploaded to {file}." : "Запись вызова в {call} была загружена в {file}.",
    "Transcript now available" : "Расшифровка теперь доступна",
    "The transcript for the call in {call} was uploaded to {file}." : "Расшифровка вызова в {call} была загружена в {file}.",
    "Failed to transcript call recording" : "Не удалось загрузить расшифровку вызова",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "Серверу не удалось расшифровать запись из {file} для вызова {call}. Пожалуйста, обратитесь к администрации.",
    "Call summary now available" : "Доступно текстовое резюме вызова",
    "The summary for the call in {call} was uploaded to {file}." : "Текстовое резюме вызова в {call} было загружено в {file}.",
    "Failed to summarize call recording" : "Не удалось резюмировать запись вызова",
    "The server failed to summarize the recording at {file} for the call in {call}. Please reach out to the administration." : "Серверу не удалось резюмировать запись из {file} для вызова {call}. Пожалуйста, обратитесь к администрации.",
    "{user1} invited you to join {roomName} on {remoteServer}" : "{user1} пригласил вас присоединиться к обсуждению {roomName} на {remoteServer}",
    "Accept" : "Принять",
    "Decline" : "Отклонить",
    "{user1} invited you to a federated conversation" : "{user} пригласил(а) вас в федеративное обсуждение",
    "Someone reacted" : "Кто-то отреагировал",
    "New message" : "Создать сообщение",
    "Reminder" : "Напоминание",
    "Someone mentioned you" : "Кто-то упомянул вас",
    "Notification" : "Уведомление",
    "Someone reacted in a private conversation" : "Кто-то отреагировал в частном обсуждении",
    "You received a message in a private conversation" : "Вы получили сообщение в частном обсуждении",
    "Reminder in a private conversation" : "Напоминание в частном обсуждении",
    "Someone mentioned you in a private conversation" : "Кто-то упомянул вас в частном обсуждении",
    "Notification in a private conversation" : "Уведомление в частном обсуждении",
    "Reminder: You in {call}" : "Напоминание: Вы в {call}",
    "Reminder: {user} in {call}" : "Напоминание: {user} в {call}",
    "Reminder: Deleted user in {call}" : "Напоминание: удалённый пользователь в {call}",
    "Reminder: {guest} (guest) in {call}" : "Напоминание: {guest} (гость) в {call}",
    "Reminder: Guest in {call}" : "Напоминание: Гость в {call}",
    "{user} reacted with {reaction}" : "{user} отреагировал(а) с {reaction}",
    "{user} reacted with {reaction} in {call}" : "{user} отреагировал(а) с {reaction} в {call}",
    "Deleted user reacted with {reaction} in {call}" : "Удалённый пользователь отреагировал с {reaction} в {call}",
    "{guest} (guest) reacted with {reaction} in {call}" : "{guest} (гость) отреагировал(а) с {reaction} в {call}",
    "Guest reacted with {reaction} in {call}" : "Гость отреагировал с {reaction} в {call}",
    "{user} in {call}" : "{user} в {call}",
    "Deleted user in {call}" : "Удалённый пользователь в {call}",
    "{guest} (guest) in {call}" : "{guest} (гость) в {call}",
    "Guest in {call}" : "Гость в {call}",
    "{user} sent you a private message" : "{user} отправил(а) Вам личное сообщение",
    "{user} sent a message in conversation {call}" : "{user} отправил(а) сообщение в обсуждении {call}",
    "A deleted user sent a message in conversation {call}" : "Удалённый пользователь отправил сообщение в обсуждении {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (гость) отправил(а) сообщение в обсуждении {call}",
    "A guest sent a message in conversation {call}" : "Гость отправил сообщение в обсуждении {call}",
    "{user} replied to your private message" : "{user} ответил(а) на ваше личное сообщение",
    "{user} replied to your message in conversation {call}" : "{user} ответил(а) на ваше сообщение в обсуждении {call}",
    "A deleted user replied to your message in conversation {call}" : "Удалённый пользователь ответил на ваше сообщение в обсуждении {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (гость) ответил(а) на ваше сообщение в обсуждении {call}",
    "A guest replied to your message in conversation {call}" : "Гость ответил на ваше сообщение в обсуждении {call}",
    "Reminder: You in private conversation {call}" : "Напоминание: Вы в частном обсуждении {call}",
    "Reminder: A deleted user in private conversation {call}" : "Напоминание: удалённый пользователь в частном обсуждении {call}",
    "Reminder: {user} in private conversation" : "Напоминание: {user} в частном обсуждении",
    "Reminder: You in conversation {call}" : "Напоминание: Вы в обсуждении {call}",
    "Reminder: {user} in conversation {call}" : "Напоминание: {user} в обсуждении {call}",
    "Reminder: A deleted user in conversation {call}" : "Напоминание: удалённый пользователь в обсуждении {call}",
    "Reminder: {guest} (guest) in conversation {call}" : "Напоминание: {guest} (гость) в обсуждении {call}",
    "Reminder: A guest in conversation {call}" : "Напоминание: Гость в обсуждении {call}",
    "{user} reacted with {reaction} to your private message" : "{user} отреагировал(а) с {reaction} на ваше личное сообщение",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user} отреагировал(а) с {reaction} на ваше сообщение в обсуждении {call}",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "Удалённый пользователь отреагировал с {reaction} на ваше сообщение в обсуждении {call}",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest} (гость) отреагировал(а) с {reaction} на ваше сообщение в обсуждении {call}",
    "A guest reacted with {reaction} to your message in conversation {call}" : "Гость отреагировал с {reaction} на ваше сообщение в обсуждении {call}",
    "{user} mentioned you in a private conversation" : "{user} упомянул(а) Вас в частном обсуждении",
    "{user} mentioned group {group} in conversation {call}" : "{user} упомянул(а) группу {group} в обсуждении {call}",
    "{user} mentioned team {team} in conversation {call}" : "{user} упомянул(а) команду {team} в обсуждении {call}",
    "{user} mentioned everyone in conversation {call}" : "{user} упомянул(а) всех в обсуждении {call}",
    "{user} mentioned you in conversation {call}" : "{user} упомянул(а) Вас в обсуждении {call}",
    "A deleted user mentioned group {group} in conversation {call}" : "Удалённый пользователь упомянул группу {group} в обсуждении {call}",
    "A deleted user mentioned team {team} in conversation {call}" : "Удалённый пользователь упомянул команду {team} в обсуждении {call}",
    "A deleted user mentioned everyone in conversation {call}" : "Удалённый пользователь упомянул всех в обсуждении {call}",
    "A deleted user mentioned you in conversation {call}" : "Удалённый пользователь упомянул Вас в обсуждении {call}",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "{guest} (гость) упомянул(а) группу {group} в обсуждении {call}",
    "{guest} (guest) mentioned team {team} in conversation {call}" : "{guest} (гость) упомянул(а) команду {team} в обсуждении {call}",
    "{guest} (guest) mentioned everyone in conversation {call}" : "{guest} (гость) упомянул(а) всех в обсуждении {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (гость) упомянул(а) Вас в обсуждении {call}",
    "A guest mentioned group {group} in conversation {call}" : "Гость упомянул группу {group} в обсуждении {call}",
    "A guest mentioned team {team} in conversation {call}" : "Гость упомянул команду {team} в обсуждении {call}",
    "A guest mentioned everyone in conversation {call}" : "Гость упомянул всех в обсуждении {call}",
    "A guest mentioned you in conversation {call}" : "Гость упомянул Вас в обсуждении {call}",
    "View message" : "Просмотреть сообщение",
    "Dismiss reminder" : "Отменить напоминание",
    "View chat" : "Просмотреть чат",
    "{user} invited you to a group conversation: {call}" : "{user} пригласил(а) вас в групповое обсуждение {call}",
    "Join call" : "Присоединиться к вызову",
    "Answer call" : "Ответить на вызов",
    "{user} would like to talk with you" : "{user} хочет начать с Вами обсуждение",
    "Call back" : "Перезвонить",
    "You missed a call from {user}" : "Вы пропустили вызов от {user}",
    "Accept call" : "Принять вызов",
    "Incoming phone call from {call}" : "Входящий телефонный вызов от {call}",
    "You missed a phone call from {call}" : "Вы пропустили телефонный вызов от {call}",
    "A group call has started in {call}" : "Вызов начался в обсуждении {call}",
    "You missed a group call in {call}" : "Вы пропустили вызов в обсуждении {call}",
    "{email} is requesting the password to access {file}" : "{email} запрашивает пароль для доступа к файлу «{file}»",
    "{email} tried to request the password to access {file}" : "Попытка запроса пароля от {email} для доступа к «{file}»",
    "Someone is requesting the password to access {file}" : "Кто-то запрашивает пароль для доступа к файлу «{file}»",
    "Someone tried to request the password to access {file}" : "Кто-то пытался запросить пароль для доступа к «{file}»",
    "Open settings" : "Открыть настройки",
    "Hosted signaling server added" : "Размещённый сигнальный сервер добавлен",
    "The hosted signaling server is now configured and will be used." : "Размещённый сигнальный сервер настроен и готов к использованию.",
    "Hosted signaling server removed" : "Размещённый сигнальный сервер удален",
    "The hosted signaling server was removed and will not be used anymore." : "Размещенный сигнальный сервер был удален и больше не будет использоваться.",
    "Hosted signaling server changed" : "Размещённый сигнальный сервер изменен",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "Состояние учётной записи размещённого сигнального сервера изменено с «{oldstatus}» на «{newstatus}».",
    "pending" : "ожидается",
    "active" : "активно",
    "expired" : "истёк",
    "blocked" : "заблокирован",
    "error" : "ошибка",
    "The certificate of {host} expires in {days} days" : "Сертификат {host} истечет через {days} дней",
    "The certificate of {host} expired" : "Сертификат {host} истёк",
    "Contact via Talk" : "Связаться через Конференции",
    "Open Talk" : "Перейти в Конференции",
    "Default" : "По умолчанию",
    "Send messages, create threads, and start voice and video calls." : "Отправляйте сообщения, создавайте темы и начинайте аудио- и видеовызовы.",
    "Presentation" : "Презентация",
    "Voice room" : "Голосовой чат",
    "Directly join the call, ideal for catch-ups or spontaneous meetings." : "Напрямую присоединяйтесь к вызову: идеально для спонтанных встреч",
    "Webinar" : "Вебинар",
    "Conversations" : "Обсуждения",
    "Messages in current conversation" : "Сообщения в текущем обсуждении",
    "{user}" : "{user}",
    "Messages" : "Сообщения",
    "{user} in {conversation}" : "{user} в {conversation}",
    "Messages in other conversations" : "Сообщения в других обсуждениях",
    "One-to-one rooms always need to show the other users avatar" : "Личные чаты всегда должны показывать аватар собеседника",
    "Invalid emoji character" : "Недопустимый символ эмодзи",
    "Invalid background color" : "Недопустимый цвет фона",
    "Avatar image is not square" : "Изображение аватара не квадратное",
    "Room {number}" : "Комната {number}",
    "Other" : "Другое",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "Не удалось запросить пробный период использования, сервер недоступен, попытайтесь повторить запрос через некоторое время.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "Не удалось проверить подлинность этого сервера, возможно он не прошёл проверку адреса, т.к. недоступен из интернета.",
    "Something unexpected happened." : "Произошла неожиданная ошибка.",
    "The URL is invalid." : "URL указан некорректно.",
    "An HTTPS URL is required." : "Необходимо указать HTTPS URL.",
    "The email address is invalid." : "Адрес электронной почты указан некорректно.",
    "The language is invalid." : "Язык указан некорректно.",
    "The country is invalid." : "Страна указана некорректно.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "Не удалось запросить пробный период, дополнительная информация сохранена в файлах журналов.",
    "Too many requests are send from your servers address. Please try again later." : "С адреса этого сервера поступило слишком много запросов, попытайтесь повторить через некоторое время.",
    "There is already a trial registered for this Nextcloud instance." : "Для этого сервера уже предоставлен пробный период использования.",
    "Something unexpected happened. Please try again later." : "Произошла неожиданная ошибка, попытайтесь позднее.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "Не удалось запросить пробный период использования, так как от вашего сервера получены неожиданные данные. Попытайтесь повторить запрос через некоторое время.",
    "Trial requested but failed to get account information. Please check back later." : "Запрос пробного периода получен, но не удалось получить информацию об учётных данных, попытайтесь повторить запрос через некоторое время.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "Не удалось проверить подлинность запроса, возможно ваш сервер не прошёл проверку адреса, так как недоступен из интернета.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "Не удалось запросить пробный период использования, так как от сервера, предоставляющего эту услугу, получены неожиданные данные. Попытайтесь повторить запрос через некоторое время.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "Не удалось получить данные об учётной записи, более подробные сведения приведены в файлах журналов.",
    "There is no such account registered." : "Указанная учётная запись не зарегистрирована.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "Не удалось получить сведения об учётной записи, т.к. недоступен сервер, предоставляющий услугу на пробный период.",
    "Deleting the hosted signaling server account failed. Please check back later." : "Не удалось удалить учётную запись сигнального сервера, повторите попытку через некоторое время.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "Не удалось удалить учётную запись, так как от сервера, предоставляющего эту услугу, получены неожиданные данные. Попытайтесь повторить запрос через некоторое время.",
    "There is a problem with deleting the account. Please check your logs for further information." : "Не удалось удалить учётную запись, более подробные сведения приведены в файлах журналов.",
    "Too many requests are sent from your servers address. Please try again later." : "С адреса этого сервера поступило слишком много запросов, попытайтесь повторить через некоторое время.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "Не удалось удалить учётную запись, т.к. недоступен сервер, предоставляющий услугу на пробный период. Попытайтесь повторить через некоторое время.",
    "Note to self" : "Личные заметки",
    "A place for your private notes, thoughts and ideas" : "Место для ваших личных заметок, мыслей и идей",
    "Transcript is AI generated and may contain mistakes" : "Расшифровка сгенерирована при помощи AI и может быть неточной",
    "Summary is AI generated and may contain mistakes" : "Резюме сгенерировано при помощи AI и может быть неточным",
    "Let's get started!" : "Давайте начнём!",
    "**Nextcloud Talk** is a secure, self-hosted communication platform that integrates seamlessly with the Nextcloud ecosystem.\n\n#### Key Features of Nextcloud Talk:\n\n* Chat and messaging in private and group chats\n* Voice and video calls\n* File sharing and integration with other Nextcloud apps\n* Customizable conversation settings, moderation and privacy controls\n* Web, desktop and mobile (iOS and Android)\n* Private & secure communication\n\n Find out more in the [user documentation](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html)." : "**Nextcloud Talk** - это безопасная коммуникационная платформа на собственном хостинге, которая легко интегрируется в экосистему Nextcloud.\n\n#### Ключевые особенности Nextcloud Talk:\n\n* Чат и обмен сообщениями в личных и групповых чатах.\n* Голосовые и видео-вызовы\n* Обмен файлами и интеграция с другими приложениями Nextcloud.\n* Настраиваемые параметры обсуждений, модерация и контроль конфиденциальности.\n* Веб-клиент, клиенты для настольных ПК и мобильных устройств (iOS и Android)\n* Частное и безопасное общение\n\nУзнайте больше в [пользовательской документации](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html).",
    "# Welcome to Nextcloud Talk\n\nNextcloud Talk is a private and powerful messaging app that integrates with Nextcloud. Chat in private or group conversations, collaborate over voice and video calls, organize webinars and events, customize your conversations and more." : "# Добро пожаловать в Nextcloud Talk\n\nNextcloud Talk - это приватный и мощный  мессенджер, интегрированный с Nextcloud. Общайтесь в частных или групповых обсуждениях, сотрудничайте с помощью голосовых и видео-вызовов, организуйте вебинары и мероприятия, настраивайте свои обсуждения и многое другое.",
    "## 🎨 Format texts to create rich messages\n\nIn Nextcloud Talk, you can use Markdown syntax to format your messages. For example, apply **bold** or *italic* formatting, or `highlight texts as code`. You can even create tables and add headings to your text.\n\nNeed to fix a typo or change formatting? Edit your message by clicking \"Edit message\" in the message menu." : "## 🎨 Форматирование текста для создания ярких сообщений\n\nВ Nextcloud Talk вы можете использовать синтаксис Markdown для форматирования сообщений. Например, применить форматирование **жирным шрифтом** или *курсивом* или `выделить текст как код`. Вы даже можете создавать таблицы и добавлять заголовки в текст.\n\nНужно исправить опечатку или изменить форматирование? Отредактируйте свое сообщение, нажав «Редактировать сообщение» в меню сообщения.",
    "## 🔗 Add attachments and links\n\nAttach files from your Nextcloud Hub using the \"+\" button. Share items from Files and various Nextcloud apps. Some apps even support interactive widgets, for example, the Text app." : "## 🔗 Добавление вложений и ссылок\n\nПрикрепляйте файлы из Nextcloud Hub с помощью кнопки «+». Делитесь элементами из «Файлов» и других приложений Nextcloud. Некоторые приложения даже поддерживают интерактивные виджеты, например, «Текст».",
    "## 💭 Let the conversations flow: mention users, react to messages and more\n\nYou can mention everybody in the conversation by using %s or mention specific participants by typing \"@\" and picking their name from the list." : "## 💭 Пусть разговоры идут своим чередом: упоминайте пользователей, реагируйте на сообщения и многое другое\n\nВы можете упомянуть всех участников обсуждения при помощи «%s», или конкретных участников, набрав «@» и выбрав имя из списка.",
    "You can reply to messages, forward them to other chats and people, or copy message content." : "Вы можете отвечать на сообщения, пересылать их в другие чаты и людям, а также копировать содержимое сообщений.",
    "## ✨ Do more with Smart Picker\n\nSimply type \"/\" or go to the \"+\" menu to open the Smart Picker where you can attach various content to your messages. You can configure the Smart Picker to be able to add items from Nextcloud apps, GIFs, map locations, AI generated content and much more." : "## ✨ Делайте больше с помощью Smart Picker\n\nПросто наберите «/» или перейдите в меню «+», чтобы открыть Smart Picker, где вы можете прикреплять к сообщениям различный контент. Вы можете настроить Smart Picker на добавление элементов из приложений Nextcloud, GIF-файлов, местоположения на карте, контента, сгенерированного ИИ, и многого другого.",
    "## ⚙️ Manage conversation settings\n\nIn the conversation menu, you can access various settings to manage your conversations, such as:\n* Edit conversation info\n* Manage notifications\n* Apply numerous moderation rules\n* Configure access and security\n* Enable bots\n* and more!" : "## ⚙️ Управление настройками обсуждения\n\nВ меню обсуждения вы можете получить доступ к различным настройкам, например:\n* Редактировать информацию об обсуждении\n* Управлять уведомлениями\n* Применять многочисленные правила модерации\n* Настроить доступ и безопасность\n* Включить ботов\n* и многое другое!",
    "Andorra" : "Андорра",
    "United Arab Emirates" : "Объединенные Арабские Эмираты",
    "Afghanistan" : "Афганистан",
    "Antigua and Barbuda" : "Антигуа и Барбуда",
    "Anguilla" : "Ангилья",
    "Albania" : "Албания",
    "Armenia" : "Армения",
    "Angola" : "Ангола",
    "Antarctica" : "Антарктика",
    "Argentina" : "Аргентина",
    "American Samoa" : "Американское Самоа",
    "Austria" : "Австрия",
    "Australia" : "Австралия",
    "Aruba" : "Аруба",
    "Åland Islands" : "Аландские острова",
    "Azerbaijan" : "Азербайджан",
    "Bosnia and Herzegovina" : "Босния и Герцеговина",
    "Barbados" : "Барбадос",
    "Bangladesh" : "Бангладеш",
    "Belgium" : "Бельгия",
    "Burkina Faso" : "Буркина-Фасо",
    "Bulgaria" : "Болгария",
    "Bahrain" : "Бахрейн",
    "Burundi" : "Бурунди",
    "Benin" : "Бенин",
    "Saint Barthélemy" : "Сен-Бартелеми",
    "Bermuda" : "Бермудские Острова",
    "Brunei Darussalam" : "Бруней",
    "Bolivia, Plurinational State of" : "Боливия",
    "Bonaire, Sint Eustatius and Saba" : "Бонэйр, Синт-Эстатиус и Саба",
    "Brazil" : "Бразилия",
    "Bahamas" : "Багамские острова",
    "Bhutan" : "Бутан",
    "Bouvet Island" : "Остров Буве",
    "Botswana" : "Ботсвана",
    "Belarus" : "Беларусь",
    "Belize" : "Белиз",
    "Canada" : "Канада",
    "Cocos (Keeling) Islands" : "Кокосовые (Килинг) острова",
    "Congo, the Democratic Republic of the" : "Конго (Демократическая Республика)",
    "Central African Republic" : "Центральная Африканская Республика",
    "Congo" : "Конго",
    "Switzerland" : "Швейцария",
    "Côte d'Ivoire" : "Кот-д’Ивуар",
    "Cook Islands" : "Острова Кука",
    "Chile" : "Чили",
    "Cameroon" : "Камерун",
    "China" : "Китай",
    "Colombia" : "Колумбия",
    "Costa Rica" : "Коста-Рика",
    "Cuba" : "Куба",
    "Cabo Verde" : "Кабо-Верде",
    "Curaçao" : "Кюрасао",
    "Christmas Island" : "Остров Рождества",
    "Cyprus" : "Кипр",
    "Czechia" : "Чехия",
    "Germany" : "Германия",
    "Djibouti" : "Джибути",
    "Denmark" : "Дания",
    "Dominica" : "Доминика",
    "Dominican Republic" : "Доминиканская Республика",
    "Algeria" : "Алжир",
    "Ecuador" : "Эквадор",
    "Estonia" : "Эстония",
    "Egypt" : "Египет",
    "Western Sahara" : "Западная Сахара",
    "Eritrea" : "Эритрея",
    "Spain" : "Испания",
    "Ethiopia" : "Эфиопия",
    "Finland" : "Финляндия",
    "Fiji" : "Фиджи",
    "Falkland Islands (Malvinas)" : "Фолкленские Острова",
    "Micronesia, Federated States of" : "Федеративные Штаты Микронезии",
    "Faroe Islands" : "Фарерские острова",
    "France" : "Франция",
    "Gabon" : "Габон",
    "United Kingdom of Great Britain and Northern Ireland" : "Соединённое Королевство Великобритании и Северной Ирландии",
    "Grenada" : "Гренада",
    "Georgia" : "Грузия",
    "French Guiana" : "Французская Гайана",
    "Guernsey" : "Гернси",
    "Ghana" : "Гана",
    "Gibraltar" : "Гибралтар",
    "Greenland" : "Гренландия",
    "Gambia" : "Гамбия",
    "Guinea" : "Гвинея",
    "Guadeloupe" : "Гваделупа",
    "Equatorial Guinea" : "Экваториальная Гвинея",
    "Greece" : "Греция",
    "South Georgia and the South Sandwich Islands" : "Южная Георгия и Южные Сандвичевы Острова",
    "Guatemala" : "Гватемала",
    "Guam" : "Гуам",
    "Guinea-Bissau" : "Гвинея-Бисау",
    "Guyana" : "Гайана",
    "Hong Kong" : "Гонконг",
    "Heard Island and McDonald Islands" : "Остров Херд и острова Макдональд",
    "Honduras" : "Гондурас",
    "Croatia" : "Хорватия",
    "Haiti" : "Гаити",
    "Hungary" : "Венгрия",
    "Indonesia" : "Индонезия",
    "Ireland" : "Ирландия",
    "Israel" : "Израиль",
    "Isle of Man" : "Остров Мэн",
    "India" : "Индия",
    "British Indian Ocean Territory" : "Британская территория Индийского океана",
    "Iraq" : "Ирак",
    "Iran, Islamic Republic of" : "Исламская Республика Иран",
    "Iceland" : "Исландия",
    "Italy" : "Италия",
    "Jersey" : "Джерси",
    "Jamaica" : "Ямайка",
    "Jordan" : "Иордания",
    "Japan" : "Япония",
    "Kenya" : "Кения",
    "Kyrgyzstan" : "Киргизия",
    "Cambodia" : "Камбожда",
    "Kiribati" : "Кирибати",
    "Comoros" : "Коморы",
    "Saint Kitts and Nevis" : "Сент-Китс и Невис",
    "Korea, Democratic People's Republic of" : "Корейская Народная Демократическая Республика (КНДР)",
    "Korea, Republic of" : "Корея",
    "Kuwait" : "Кувейт",
    "Cayman Islands" : "Каймановы острова",
    "Kazakhstan" : "Казахстан",
    "Lao People's Democratic Republic" : "Лаос",
    "Lebanon" : "Ливан",
    "Saint Lucia" : "Сент-Люсия",
    "Liechtenstein" : "Лихтенштейн",
    "Sri Lanka" : "Шри Ланка",
    "Liberia" : "Либерия",
    "Lesotho" : "Лесото",
    "Lithuania" : "Литва",
    "Luxembourg" : "Люксембург",
    "Latvia" : "Латвия",
    "Libya" : "Ливия",
    "Morocco" : "Марокко",
    "Monaco" : "Монако",
    "Moldova, Republic of" : "Молдова",
    "Montenegro" : "Черногория",
    "Saint Martin (French part)" : "Сен-Мартен (владение Франции)",
    "Madagascar" : "Мадагаскар",
    "Marshall Islands" : "Маршалловы Острова",
    "North Macedonia" : "Северная Македония",
    "Mali" : "Мали",
    "Myanmar" : "Мьянма",
    "Mongolia" : "Монголия",
    "Macao" : "Макао",
    "Northern Mariana Islands" : "Северные Марианские Острова",
    "Martinique" : "Мартиника",
    "Mauritania" : "Мавритания",
    "Montserrat" : "Монтсеррат",
    "Malta" : "Мальта",
    "Mauritius" : "Маврикий",
    "Maldives" : "Мальдивы",
    "Malawi" : "Малави",
    "Mexico" : "Мексика",
    "Malaysia" : "Малайзия",
    "Mozambique" : "Мозамбик",
    "Namibia" : "Намибия",
    "New Caledonia" : "Новая Каледония",
    "Niger" : "Нигер",
    "Norfolk Island" : "Норфолские Острова",
    "Nigeria" : "Нигерия",
    "Nicaragua" : "Никарагуа",
    "Netherlands" : "Нидерланды",
    "Norway" : "Норвегия",
    "Nepal" : "Непал",
    "Nauru" : "Науру",
    "Niue" : "Ниуэ",
    "New Zealand" : "Новая Зеландия",
    "Oman" : "Оман",
    "Panama" : "Панама",
    "Peru" : "Перу",
    "French Polynesia" : "Французская Полинезия",
    "Papua New Guinea" : "Папуа Новая Гвинея",
    "Philippines" : "Филиппины",
    "Pakistan" : "Пакистан",
    "Poland" : "Польша",
    "Saint Pierre and Miquelon" : "Сен-Пьер и Микелон",
    "Pitcairn" : "Острова Питкэрн",
    "Puerto Rico" : "Пуэрто Рико",
    "Palestine, State of" : "Палестина",
    "Portugal" : "Португалия",
    "Palau" : "Палау",
    "Paraguay" : "Парагвай",
    "Qatar" : "Катар",
    "Réunion" : "Реюньон",
    "Romania" : "Румыния",
    "Serbia" : "Сербия",
    "Russian Federation" : "Российская Федерация",
    "Rwanda" : "Руанда",
    "Saudi Arabia" : "Саудовская Аравия",
    "Solomon Islands" : "Соломоновы Острова",
    "Seychelles" : "Сейшельские Острова",
    "Sudan" : "Судан",
    "Sweden" : "Швеция",
    "Singapore" : "Сингапур",
    "Saint Helena, Ascension and Tristan da Cunha" : "Острова Святой Елены, Вознесения и Тристан-да-Кунья",
    "Slovenia" : "Словения",
    "Svalbard and Jan Mayen" : "Шпицберген и Ян-Майен",
    "Slovakia" : "Словакия",
    "Sierra Leone" : "Сьерра Леоне",
    "San Marino" : "Сан Марино",
    "Senegal" : "Сенегал",
    "Somalia" : "Сомали",
    "Suriname" : "Суринам",
    "South Sudan" : "Южный Судан",
    "Sao Tome and Principe" : "Сантоме и Принсипи",
    "El Salvador" : "Эль-Сальвадор",
    "Sint Maarten (Dutch part)" : "Синт-Мартен Королевства Нидерландов",
    "Syrian Arab Republic" : "Сирийская Арабская Республика",
    "Eswatini" : "Эсватини",
    "Turks and Caicos Islands" : "Теркс и Кайкос",
    "Chad" : "Чад",
    "French Southern Territories" : "Французские Южные Территории",
    "Togo" : "Того",
    "Thailand" : "Таиланд",
    "Tajikistan" : "Таджикистан",
    "Tokelau" : "Токелау",
    "Timor-Leste" : "Восточный Тимор",
    "Turkmenistan" : "Туркменистан",
    "Tunisia" : "Тунис",
    "Tonga" : "Тонга",
    "Turkey" : "Турция",
    "Trinidad and Tobago" : "Тринидад и Тобаго",
    "Tuvalu" : "Тувалу",
    "Taiwan, Province of China" : "Тайвань",
    "Tanzania, United Republic of" : "Танзания",
    "Ukraine" : "Украина",
    "Uganda" : "Уганда",
    "United States Minor Outlying Islands" : "Внешние малые острова США",
    "United States of America" : "Соединенные Штаты Америки",
    "Uruguay" : "Уругвай",
    "Uzbekistan" : "Узбекистан",
    "Holy See" : "Ватикан",
    "Saint Vincent and the Grenadines" : "Сант Винсент и Гренадины",
    "Venezuela, Bolivarian Republic of" : "Венесуэла",
    "Virgin Islands, British" : "Британские Вирджинские Острова",
    "Virgin Islands, U.S." : "Американские Вирджинские Острова",
    "Viet Nam" : "Вьетнам",
    "Vanuatu" : "Вануату",
    "Wallis and Futuna" : "Уоллис и Футуна",
    "Samoa" : "Самоа",
    "Yemen" : "Йемен",
    "Mayotte" : "Майотта",
    "South Africa" : "Южная Африка",
    "Zambia" : "Замбия",
    "Zimbabwe" : "Зимбабве",
    "Background blur" : "Размытие фона",
    "Could not check for WASM loading support. Please check manually if your web server serves `.wasm` files." : "Не удалось проверить поддержку загрузки WASM. Проверьте вручную, обслуживает ли ваш веб-сервер файлы `.wasm`.",
    "Your web server is not properly set up to deliver `.wasm` files. This is typically an issue with the Nginx configuration. For background blur it needs an adjustment to also deliver `.wasm` files. Compare your Nginx configuration to the recommended configuration in our documentation." : "Ваш веб-сервер неправильно настроен для доставки файлов `.wasm`. Обычно это проблема конфигурации Nginx. Для размытия фона требуется настройка, чтобы также доставлять файлы `.wasm`. Сравните вашу конфигурацию Nginx с рекомендуемой конфигурацией в нашей документации.",
    "Talk configuration values" : "Значения конфигурации Talk",
    "Forcing a call duration is only supported with system cron. Please enable system cron or remove the `max_call_duration` configuration." : "Принудительное задание продолжительности вызова поддерживается только системным cron. Включите системный cron или удалите конфигурацию `max_call_duration`.",
    "Small `max_call_duration` values (currently set to %d) are not enforceable due to technical limitations. The background job is only executed every 5 minutes, so use at own risk." : "Малые значения `max_call_duration` (в настоящее время установлено %d) не могут быть реализованы из-за технических ограничений. Фоновоя задача выполняется только каждые 5 минут, поэтому используйте его на свой риск.",
    "Federation" : "Федерация",
    "It is highly recommended to configure \"memcache.locking\" when Talk Federation is enabled." : "Настойчиво рекомендуется настроить \"memcache.locking\" когда Talk Федерации включены.",
    "High-performance backend" : "Высокопроизводительный сервер",
    "No High-performance backend configured - Running Nextcloud Talk without the High-performance backend only scales for very small calls (max. 2-3 participants). Please set up the High-performance backend to ensure calls with multiple participants work seamlessly." : "Высокопроизводительный сервер не сконфигурирован - использование Nextcloud Talk без Высокопроизводительного сервера подходит только для очень маленьких вызовов (не более 2-3 участников). Пожалуйста, настройте Высокопроизводительный сервер, чтобы обеспечить бесперебойную работу вызовов с несколькими участниками.",
    "Running the High-performance backend \"conversation_cluster\" mode is deprecated and will no longer be supported in the upcoming version. The High-performance backend supports real clustering nowadays which should be used instead." : "Режим Высокопроизводительного сервера \"conversation_cluster\" устарел и больше не будет поддерживаться в следующих версиях. Высокопроизводительный сервер теперь поддерживает настоящую кластеризацию, которую следует использовать вместо этого.",
    "Defining multiple High-performance backends is deprecated and will no longer be supported in the upcoming version. Instead a load-balancer should be set up together with clustered signaling servers and configured in the Talk settings." : "Поддержка нескольких Высокопроизводительных серверов устарела и больше не будет поддерживаться в следующих версиях. Вместо этого балансировщик нагрузки должен быть установлен вместе с кластеризованными сигнальными серверами и настроен в конфигурации Talk.",
    "The stored public key for used algorithm %1$s does not match the stored private key. Run %2$s to fix the issue." : "Сохранённый открытый ключ для алгоритма %1$s не совпадает с сохранённым приватным ключом. Выполните %2$s чтобы исправить проблему.",
    "High-performance backend not configured correctly. Run %s for details." : "Высокопроизводительный сервер неверно сконфигурирован. Выполните %s для получения деталей.",
    "High-performance backend not configured correctly" : "Высокопроизводительный сервер неверно сконфигурирован",
    "Error: Cannot connect to server" : "Ошибка: Не могу подключиться к серверу",
    "Error: Server did not respond with proper JSON" : "Ошибка: Сервер вернул неверный JSON",
    "Error: Certificate expired" : "Ошибка: Сертификат истёк",
    "Error: System times of Nextcloud server and High-performance backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Ошибка: Системное время сервера Nextcloud и Высокопроизводительного сервера не синхронизировано. Убедитесь, что оба сервера подключены к серверу времени, или вручную синхронизируйте их время.",
    "Could not get version" : "Не удалось получить версию",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "Ошибка: Текущая версия: {version}; Сервер необходимо обновить для совместимости с этой версией Talk",
    "Error: Server responded with: {error}" : "Ошибка: Ответ сервера: {error}",
    "Error: Unknown error occurred" : "Ошибка: Произошла неизвестная ошибка",
    "Warning: Running version: {version}; Server does not support all features of this Talk version, missing features: {features}" : "Внимание: Текущая версия: {version}; Сервер не поддерживает все функции этой версии Talk, недоступные функции: {features}",
    "It is highly recommended to configure a memory cache when running Nextcloud Talk with a High-performance backend." : "Настойчиво рекомендуется настроить распределенный кэш для использования Nextcloud Talk совместно с Высокопроизводительным сервером.",
    "Client Push" : "Client Push",
    "Client Push is installed, this improves the punctuality of Talk notifications." : "«Client Push» установлен, это улучшает скорость получения уведомлений в Talk",
    "{notify_push} is not installed. This may lead to delayed Talk notifications." : "«{notify_push}»  не установлен, это может привести к замедленному получению уведомлений в Talk",
    "Recording backend" : "Сервер записи вызовов",
    "Using the recording backend requires a High-performance backend." : "Использование сервера для записи вызовов требует для работы Высокопроизводительный сервер",
    "No recording backend configured" : "Сервер записи вызовов не настроен",
    "SIP configuration" : "Параметры SIP",
    "Using the SIP functionality requires a High-performance backend." : "Использование функционала SIP требует для работы Высокопроизводительный сервер",
    "Assigned Talk phone numbers must not start with + or 0. Please remove or update the following numbers:\n{list}" : "Назначенные номера телефонов Talk не должны начинаться с + или 0. Пожалуйста, удалите или обновите следующие номера:\n{list}",
    "No SIP backend configured" : "Сервер SIP не настроен",
    "Invalid date, date format must be YYYY-MM-DD" : "Неверная дата, дата должна быть в формате «ГГГГ-ММ-ДД»",
    "Conversation not found" : "Обсуждение не найдено",
    "Path is already shared with this conversation" : "Этот путь уже опубликован в обсуждении",
    "Chat, video & audio-conferencing using WebRTC" : "Чат, видео- и аудиоконференции, основанные на технологии WebRTC",
    "Chat, video & audio-conferencing using WebRTC\n\n* 💬 **Chat** Nextcloud Talk comes with a simple text chat, allowing you to share or upload files from your Nextcloud Files app or local device and mention other participants.\n* 👥 **Private, group, public and password protected calls!** Invite someone, a whole group or send a public link to invite to a call.\n* 🌐 **Federated chats** Chat with other Nextcloud users on their servers\n* 💻 **Screen sharing!** Share your screen with the participants of your call.\n* 🚀 **Integration with other Nextcloud apps** like Files, Calendar, User status, Dashboard, Flow, Maps, Smart picker, Contacts, Deck, and many more.\n* 🌉 **Sync with other chat solutions** With [Matterbridge](https://github.com/42wim/matterbridge/) being integrated in Talk, you can easily sync a lot of other chat solutions to Nextcloud Talk and vice-versa." : "Мессенджер, видео- и аудио-конференции с использованием WebRTC\n\n* 💬 **Мессенджер** Nextcloud Talk предлагает простой чат для обмена сообщениями, позволяя делиться или загружать файлы из вашего приложения Nextcloud Files или устройства и упоминать других участников.\n* 👥 **Персональные, групповые, публичные и защищенные паролем звонки!** Пригласите человека, целую группу или отправьте публичную ссылку чтобы пригласить в вызов.\n* 🌐 **Федеративные обсуждения** Обменивайтесь сообщениями с другими пользователями Nextcloud на удаленном сервере\n* 💻 **Демонстрация экрана!** Делитесь своим экраном с участниками вызова.\n* 🚀 **Интеграция с другими приложениями Nextcloud** как Файлы, Календарь, Состояние, Виджеты, Обработка файлов, Карты, Умный выбор, Контакты, Карточки, и другие.\n* 🌉 **Синхронизация с другими мессенджерами** С помощью [Matterbridge](https://github.com/42wim/matterbridge/) интегрированного в Talk, вы легко можете синхронизировать множество других мессенджеров и решений с Nextcloud Talk и наоборот.",
    "Leave call" : "Покинуть вызов",
    "Navigating away from the page will leave the call in {conversation}" : "При переходе с этой страницы вы покинете вызов в {conversation}",
    "Stay in call" : "Не покидать вызов",
    "Error occurred when getting the conversation information" : "Произошла ошибка при получении информации об обсуждении",
    "Discuss this file" : "Обсудить этот файл",
    "Share this file with others to discuss it" : "Опубликовать этот файл для обсуждения",
    "Share this file" : "Опубликовать файл",
    "Join conversation" : "Присоединиться к обсуждению",
    "This conversation is password-protected." : "Это обсуждение защищено паролем.",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "С вашего IP-адреса было выполнено множество неудачных попыток входа в систему. Следующую попытку можно будет выполнить через 30 секунд.",
    "The password is wrong. Try again." : "Неверный пароль. Попробуйте еще раз.",
    "Password" : "Пароль",
    "Submit" : "Отправить ответ",
    "Error requesting the password." : "Ошибка запроса пароля",
    "Request password" : "Запрос пароля",
    "This conversation has ended" : "Обсуждение закончено",
    "Error occurred when joining the conversation" : "Произошла ошибка при присоединении к обсуждению",
    "Close Talk sidebar" : "Закрыть боковую панель",
    "Open Talk sidebar" : "Открыть боковую панель",
    "Everyone" : "Все",
    "Users and moderators" : "Пользователи и модераторы",
    "Moderators only" : "Только модераторы",
    "Disable calls" : "Отключить вызовы",
    "Save changes" : "Сохранить изменения",
    "Saving …" : "Сохранение…",
    "Saved!" : "Сохранено!",
    "Limit to groups" : "Разрешить использование только участникам этих групп",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Когда выбрана хотя бы одна группа, только участники перечисленных групп могут участвовать в обсуждениях.",
    "Guests can still join public conversations." : "Ограничения не распространяются на гостей в открытых обсуждениях.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Пользователи, которые больше не смогут использовать приложение «Talk», всё ещё будут перечислены, как участники своих прошлых обсуждений, а их сообщения будут сохранены.",
    "Limit using Talk" : "Ограничить использование Talk",
    "Limit creating a public and group conversation" : "Ограничить создание открытых и групповых обсуждений",
    "Limit creating conversations" : "Ограничить создание обсуждений",
    "Limit starting a call" : "Ограничить возможность начинать вызов",
    "Limit starting calls" : "Ограничить возможность начинать вызов",
    "When a call has started, everyone with access to the conversation can join the call." : "Присоединиться к выполняемому вызову могут все, обладающими правами доступа к обсуждению.",
    "The following bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Следующие боты установлены на этом сервере. В документации вы можете найти подробную информацию о том, как {linkstart1}создать собственного бота{linkend}, или {linkstart2}список ботов{linkend}, которых можно включить на вашем сервере.",
    "No bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Ни один бот не установлен на этом сервере. В документации вы можете найти подробную информацию о том, как {linkstart1}создать собственного бота{linkend}, или {linkstart2}список ботов{linkend}, которых можно включить на вашем сервере.",
    "Description is not provided" : "Описание не предоставлено",
    "Locked for moderators" : "Заблокировано для модераторов",
    "Enabled" : "Включено",
    "Disabled" : "Отключено",
    "Bots settings" : "Настройки ботов",
    "State" : "Состояние",
    "Name" : "Название",
    "Last error" : "Последняя ошибка",
    "Total errors count" : "Общее количество ошибок",
    "Find more bots" : "Найти больше ботов",
    "Trusted servers can be configured at {linkstart}Sharing settings page{linkend}." : "Доверенные серверы можно настроить на {linkstart}странице настроек обмена{linkend}.",
    "Beta" : "Бета",
    "Federated chats and calls work already. Attachment handling is coming in a future version." : "Обмен сообщениями и вызовы в федеративных обсуждениях работают. Обмен файлами появится в будущих версиях.",
    "Enable Federation in Talk app" : "Включить Федерацию в приложении Talk",
    "Permissions" : "Права доступа",
    "Allow users to be invited to federated conversations" : "Разрешить пользователям быть приглашенными в федеративные обсуждения",
    "Allow users to invite federated users into conversation" : "Разрешить пользователям приглашать федеративных пользователей в обсуждение",
    "Only allow to federate with trusted servers" : "Разрешить федерации только с доверенными серверами",
    "When at least one group is selected, only people of the listed groups can invite federated users to conversations." : "Когда выбрана хотя бы одна группа, только участники перечисленных групп могут приглашать федеративных пользователей в обсуждения.",
    "Groups allowed to invite federated users" : "Группы, которым разрешено приглашать федеративных пользователей",
    "Select groups …" : "Выбрать группы …",
    "All messages" : "Все сообщения",
    "@-mentions only" : "Только @-упоминания",
    "Off" : "Отключить",
    "General settings" : "Основные настройки",
    "Default notification settings" : "Настройки уведомлений по умолчанию",
    "Default group notification" : "Групповое уведомление по умолчанию:",
    "Default group notification for new groups" : "Уведомление для новых групп по умолчанию",
    "Integration into other apps" : "Встраивание в другие приложения",
    "Allow conversations on files" : "Разрешить обсуждения файлов",
    "Allow conversations on public shares for files" : "Разрешить создание обсуждений для общедоступных файлов",
    "End-to-end encrypted calls" : "Вызовы со сквозным шифрованием",
    "Enable encryption" : "Включить шифрование",
    "End-to-end encrypted calls with a configured SIP bridge require a newer version of the High-performance backend and SIP bridge." : "Для вызовов со сквозным шифрованием с настроенным SIP-мостом требуется более новая версия Высокопроизводительного сервера и SIP-моста.",
    "Mobile clients do not support end-to-end encrypted calls at the moment." : "Мобильные устройства на данный момент не поддерживают сквозное шифрование вызовов.",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "При нажатии кнопки, расположенной выше, заполненные данные формы будут переданы на серверы компании Struktur AG. Дополнительные сведения представлены на сайте {linkstart}spreed.eu{linkend}.",
    "Pending" : "Ожидается",
    "Error" : "Ошибка",
    "Blocked" : "Заблокировано",
    "Active" : "Активно",
    "Expired" : "Истекло",
    "Never" : "Никогда",
    "The trial could not be requested. Please try again later." : "Не удалось запросить пробный период использования, повторите попытку через некоторое время.",
    "The account could not be deleted. Please try again later." : "Аккаунт не может быть удален. Повторите попытку позже.",
    "Hosted High-performance backend" : "Размещенный Высокопроизводительный сервер",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Struktur AG, партнёр Nextcloud, предоставляет возможность запросить запросить использование размещаемого сигнального сервера. Для получения доступа требуется заполнить приведённую ниже форму. После настройки сервера данные для подключения будут заполнены автоматически. Внимание: это действие перезапишет существующие параметры сигнального сервера.",
    "If your high-performance backend account includes STUN and/or TURN functionality, the settings will be updated accordingly." : "Если ваш аккаунт Высокопроизводительного сервера включает STUN и/или TURN, настройки будут обновлены автоматически.",
    "URL of this Nextcloud instance" : "URL данного сервера Nextcloud",
    "Full name of the user requesting the trial" : "Полное имя пользователя, запрашивающего пробную версию",
    "Email of the user" : "Адрес эл.почты пользователя",
    "Language" : "Язык",
    "Country" : "Страна",
    "Request signaling server trial" : "Запросить пробную версию сигнального сервера",
    "You can see the current status of your hosted signaling server in the following table." : "Вы можете просматривать статус вашего сигнального сервера в таблице ниже.",
    "Status" : "Статус",
    "Created at" : "Создано",
    "Expires at" : "Истекает",
    "Limits" : "Ограничения",
    "STUN included" : "STUN включён",
    "Yes" : "Да",
    "No" : "Нет",
    "TURN included" : "TURN включён",
    "Delete the signaling server account" : "Удалить аккаунт сигнального сервера",
    "_%n user_::_%n users_" : ["%n пользователь","%n пользователя","%n пользователей","%n пользователя"],
    "Installed version: {version}" : "Установленная версия: {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "Вы можете установить Matterbridge, чтобы связать Nextcloud Talk с некоторыми другими сервисами. Подробную информацию можно найти на их {linkstart1}странице GitHub{linkend}. Загрузка и установка приложения может занять некоторое время. Если время ожидания истекло, установите его вручную из {linkstart2}Nextcloud App Store{linkend}.",
    "Matterbridge binary has incorrect permissions. Please make sure the Matterbridge binary file is owned by the correct user and can be executed. It can be found in \"/…/nextcloud/apps/talk_matterbridge/bin/\"." : "Исполняемому файлу Matterbridge назначены неверные права доступа. Убедитесь, что файлу назначен верный владелец и права на исполнение. Файл расположен в каталоге «/…/nextcloud/apps/talk_matterbridge/bin/».",
    "Matterbridge binary was not found or couldn't be executed." : "Исполняемый файл Matterbridge не найден или не может быть запущен.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "Расположение исполняемых файлов Matterbridge может быть заданно вручную в файле конфигурации. Дополнительные сведения представлены в {linkstart}документации по настройке Matterbridge{linkend}.",
    "Downloading …" : "Загрузка…",
    "Install Talk Matterbridge" : "Установить Talk Matterbridge",
    "An error occurred while installing the Matterbridge app" : "Не удалось установить приложение Matterbridge",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "Не удалось установить Talk Matterbridge, установите его вручную",
    "Failed to execute Matterbridge binary." : "Не удалось запустить исполняемый файл Matterbridge.",
    "Matterbridge integration" : "Интеграция Matterbridge",
    "Enable Matterbridge integration" : "Включить Matterbridge",
    "Status: Checking connection" : "Статус: Проверка соединения",
    "OK: Running version: {version}" : "OK: Текущая версия: {version}",
    "Error: Server seems to be a Signaling server" : "Ошибка: сервер являетcя сигнальным сервером",
    "Error: System times of Nextcloud server and Recording backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Ошибка: Системное время сервера Nextcloud и сервера записи вызовов не синхронизировано. Убедитесь, что оба сервера подключены к серверу времени, или вручную синхронизируйте их время.",
    "Recording backend URL" : "URL сервера записи вызовов",
    "Validate SSL certificate" : "Проверять сертификат SSL",
    "Delete this server" : "Удалить этот сервер",
    "Test this server" : "Проверить сервер",
    "Disabled for all calls" : "Отключено для всех вызовов",
    "Enabled for all calls" : "Включено для всех вызовов",
    "Configurable on conversation level by moderators" : "Настраиваемо модераторами на уровне обсуждения",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "Настройки PHP \"upload_max_filesize\" или \"post_max_size\" позволяют загружать только файлы размером до {maxUpload}.",
    "Recording backend settings saved" : "Настройки бэкенда записи ВКС сохранены",
    "Moderators will be allowed to enable consent on conversation level. The consent to be recorded will be required for each participant before joining every call in this conversation." : "Модераторам будет разрешено включать согласие на запись на уровне обсуждения. Подтвержденное согласие будет требоваться от каждого участника перед присоединением к каждому вызову в этом обсуждении.",
    "The consent to be recorded will be required for each participant before joining every call." : "Согласие на запись будет требоваться от каждого участника перед присоединением к каждому вызову.",
    "The consent to be recorded is not required." : "Согласие на запись не требуется.",
    "Recording backend configuration is only possible with a High-performance backend." : "Конфигурация сервера для записи вызовов возможна только с Высокопроизводительным сервером.",
    "Add a new recording backend server" : "Добавить новый сервер записи вызовов",
    "Shared secret" : "Общая секретная фраза",
    "Recording consent" : "Согласие на запись вызова",
    "Recording transcription" : "Расшифровка записей вызовов",
    "Automatically transcribe call recordings with a transcription provider" : "Автоматическая расшифровка записей вызовов с помощью приложения - транскриптора",
    "Automatically summarize call recordings with transcription and summary providers" : "Автоматическое резюме записей вызовов с помощью приложений - транскриптора и резюме",
    "SIP configuration saved!" : "Параметры SIP сохранены",
    "SIP configuration is only possible with a High-performance backend." : "Конфигурация SIP возможна только с Высокопроизводительным сервером.",
    "Enable SIP Dial-out option" : "Включить опцию исходящего вызова по SIP",
    "Signaling server needs to be updated to supported SIP Dial-out feature." : "Сигнальный сервер необходимо обновить для поддержки функции исходящего вызова по SIP.",
    "Do not show SIP Dial-out caller number" : "Не показывать номер исходящего вызова по SIP",
    "Anonymous number should appear as \"unknown\" or \"withheld number\" to call recipient" : "Анонимный номер должен отобразиться как \"Неизвестный\" или \"Номер скрыт\" для ответчика",
    "Dial-out number" : "Номер исходящего вызова",
    "E164 formatted number used as a fallback caller number for outgoing calls" : "Номер в формате E164, используемый как резервный номер звонящего для исходящих вызовов",
    "Dial-out prefix" : "Префикс исходящего вызова",
    "Prefix to configured user number for outgoing calls (default is `+`)" : "Префикс к номеру пользователя для исходящих вызовов (`+` по умолчанию)",
    "Restrict SIP configuration" : "Ограничить возможность настройки SIP",
    "Enable SIP configuration" : "Выберите группы, которым разрешено использовать SIP",
    "Only users of the following groups can enable SIP in conversations they moderate" : "Разрешить использование протокола SIP только пользователям указанных групп в модерируемых ими конференциях",
    "Phone number (Country)" : "Номер телефона",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Эти сведения будут добавлены в письма-приглашения и показаны всем участникам в боковой панели.",
    "Nextcloud base URL" : "Адрес сервера Nextcloud (base URL)",
    "Talk Backend URL" : "Адрес сервера Talk (Backend URL)",
    "WebSocket URL" : "WebSocket URL",
    "Available features" : "Доступные возможности",
    "Error: Websocket connection failed" : "Ошибка при установлении Websocket соединения",
    "Error code" : "Код ошибки",
    "Error message" : "Сообщение ошибки",
    "Error: Websocket connection failed. Check browser console" : "Ошибка при установлении Websocket соединения. Проверьте консоль браузера",
    "High-performance backend URL" : "URL Высокопроизводительного сервера",
    "Missing High-performance backend warning hidden" : "Скрыто предупреждение об отсутствующем Высокопроизводительном сервере",
    "High-performance backend settings saved" : "Параметры Высокопроизводительного сервера сохранены",
    "Nextcloud Talk setup not complete" : "Конфигурация Nextcloud Talk не завершена",
    "Please note that in calls with more than 2 participants without the High-performance backend, participants will most likely experience connectivity issues and cause high load on participating devices." : "Обратите внимание, что в вызовах с более чем 2 участниками без Высокопроизводительного сервера, участники могут испытывать проблемы со связью и получать сильную нагрузку на свои устройства.",
    "Install the High-performance backend to ensure calls with multiple participants work seamlessly." : "Установите Высокопроизводительный сервер, чтобы вызовы с несколькими участниками работали корректно.",
    "Nextcloud portal" : "Nextcloud портал",
    "Quick installation guide" : "Краткое руководство по установке",
    "The High-performance backend is required for calls and conversations with multiple participants. Without the backend, all participants have to upload their own video individually for each other participant, which will most likely cause connectivity issues and a high load on participating devices." : "Высокопроизводительный сервер необходим для вызовов и обсуждений с несколькими участниками. Без сервера всем участникам придется загружать свое видео отдельно для каждого собеседника, что, скорее всего, приведет к проблемам со связью и высокой нагрузке на используемые устройства.",
    "It is highly recommended to set up a distributed cache when using Nextcloud Talk with a High-performance backend." : "Настойчиво рекомендуется настроить распределенный кэш для использования Nextcloud Talk совместно с Высокопроизводительным сервером.",
    "Add High-performance backend server" : "Добавить Высокопроизводительный сервер",
    "Warn about connectivity issues in calls with more than 2 participants" : "Предупреждать о проблемах со связью в вызовах с более чем 2 участниками",
    "STUN server URL" : "URL cервера STUN",
    "The server address is invalid" : "Указан недействительный адрес сервера",
    "STUN settings saved" : "Параметры STUN сохранены",
    "STUN servers" : "Сервер STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Сервер STUN используется для определения общедоступного IP адреса участников за маршрутизатором.",
    "Add a new STUN server" : "Добавить сервер STUN",
    "{schema} scheme must be used with a domain" : "использование схемы {schema} возможно только в домене",
    "{option1} and {option2}" : "{option1} и {option2}",
    "{option} only" : "только {option}",
    "OK: Successful ICE candidates returned by the TURN server" : "OK: кандидаты ICE получены с сервера TURN",
    "Error: No working ICE candidates returned by the TURN server" : "Ошибка: работоспособные кандидаты ICE не получены с сервера TURN",
    "Testing whether the TURN server returns ICE candidates" : "Проверка получения кандидатов ICE с сервера TURN",
    "TURN server schemes" : "Схемы сервера TURN",
    "TURN server URL" : "URL сервера TURN",
    "TURN server secret" : "Секретный ключ TURN-сервера",
    "TURN server protocols" : "Протоколы сервера TURN",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "Сервер TURN (Traversal Using Relay NAT) используется для перенаправления данных для участников, расположенных за брандмауэром. Сервер TURN необходим, если участники не могут устанавливать прямое соединение. Сведения по настройке приведены в {linkstart}документации{linkend}.",
    "TURN settings saved" : "Параметры TURN сохранены",
    "TURN servers" : "TURN-серверы",
    "Add a new TURN server" : "Добавить сервер TURN",
    "Failed" : "Не удалось",
    "OK" : "ОК",
    "Checking …" : "Проверка...",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "Не удалось: WebAssembly отключена или не поддерживается в этом браузере. Пожалуйста, включите WebAssembly или используйте браузер с его поддержкой для выполнения проверки.",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "Не удалось: Файлы \".wasm\" и \".tflite\" некорректно возвращены веб-сервером. Пожалуйста, проверьте раздел \"Системные требования\" в документации Talk.",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "OK: файлы \".wasm\" и \".tflite\" корректно возвращены веб-сервером.",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "Предположительно, конфигурация PHP и Apache несовместима. Обратите внимание, что PHP можно использовать только с модулем MPM_PREFORK, а PHP-FPM можно использовать только с модулем MPM_EVENT.",
    "Web server setup checks" : "Проверка настройки веб-сервера",
    "Files required for virtual background can be loaded" : "Файлы, необходимые для виртуального фона, могут быть загружены",
    "Federated user" : "Федеративный пользователь",
    "Assign participants to rooms" : "Назначить участников в комнаты",
    "Configure breakout rooms" : "Настроить комнаты обсуждения",
    "Number of breakout rooms" : "Количество комнат обсуждения",
    "You can create from 1 to 20 breakout rooms." : "Вы можете создать от 1 до 20 комнат обсуждения.",
    "Assignment method" : "Метод назначения",
    "Automatically assign participants" : "Назначить участников автоматически",
    "Manually assign participants" : "Назначить участников вручную",
    "Allow participants to choose" : "Разрешить участникам выбирать",
    "Create rooms" : "Создать комнаты обсуждения",
    "Confirm" : "Подтвердить",
    "Create breakout rooms" : "Создать комнаты обсуждения",
    "Reset" : "Сбросить",
    "Delete breakout rooms" : "Удалить комнаты обсуждения",
    "Room {roomNumber}" : "Комната {roomNumber}",
    "Current breakout rooms and settings will be lost" : "Текущие комнаты обсуждения и настройки будут сброшены",
    "Cancel" : "Отмена",
    "Unassigned participants" : "Неназначенные участники",
    "Back" : "Назад",
    "Assign" : "Назначить",
    "Add participant \"{user}\"" : "Добавить участника «{user}»",
    "Now" : "Сейчас",
    "Invalid calendar selected" : "Выбран недопустимый календарь",
    "Invalid start time selected" : "Выбрано недопустимое время старта",
    "Invalid end time selected" : "Выбрано недопустимое время окончания",
    "Unknown error occurred" : "Произошла неизвестная ошибка",
    "Sending no invitations" : "Не отправлять никаких приглашений",
    "{participant0} will receive an invitation" : "{participant0} получит приглашение",
    "{participant0} and {participant1} will receive invitations" : "{participant0} и {participant1} получат приглашения",
    "_{participant0}, {participant1} and %n other will receive invitations_::_{participant0}, {participant1} and %n others will receive invitations_" : ["{participant0}, {participant1} и ещё %n получат приглашения","{participant0}, {participant1} и ещё %n получат приглашения","{participant0}, {participant1} и ещё %n получат приглашения","{participant0}, {participant1} и ещё %n получат приглашения"],
    "Invite {user}" : "Пригласить {user}",
    "Invite all users and emails in this conversation" : "Пригласить всех пользователей и адреса эл. почты в этом обсуждении",
    "Meeting created" : "Встреча создана",
    "Upcoming meetings" : "Предстоящие встречи",
    "Loading …" : "Загрузка…",
    "No upcoming meetings" : "Нет предстоящих встреч",
    "Schedule a meeting" : "Запланировать встречу",
    "Meeting title" : "Заголовок встречи",
    "From" : "От",
    "To" : "Кому",
    "Calendar" : "Календарь",
    "Attendees" : "Участники",
    "No other participants to send invitations to." : "Нет других участников, чтобы отправить приглашения.",
    "Add attendees" : "Добавить участников",
    "Save" : "Сохранить",
    "Search participants" : "Искать участников",
    "No results" : "Нет результатов",
    "Done" : "Выполненные",
    "Disable live transcription" : "Отключить онлайн-транскрипцию",
    "Enable live transcription (generated by AI)" : "Включить онлайн-транскрипцию (генерируется с ИИ)",
    "Enable live transcription (Live transcriptions app is not installed)" : "Включить онлайн-транскрипцию (приложение не установлено)",
    "Disable live translation" : "Отключить онлайн-перевод",
    "Enable live translation (generated by AI)" : "Включить онлайн-перевод (генерируется с ИИ)",
    "Original language" : "Исходный язык",
    "Live translations app is not installed" : "Приложение для онлайн-перевода не установлно",
    "Original language: {languageName}" : "Язык оригинала: {languageName}",
    "Translated language" : "Язык для перевода",
    "Translated language: {languageName}" : "Язык для перевода: {languageName}",
    "Raise hand" : "Поднять руку",
    "Raise hand (R)" : "Поднять руку (R)",
    "Lower hand" : "Опустить руку",
    "Lower hand (R)" : "Опустить руку (R)",
    "Exit full screen (F)" : "Выйти из полноэкранного режима (F)",
    "Full screen (F)" : "Во весь экран (F)",
    "Speaker view" : "Режим показа выступающего",
    "Grid view" : "Вид сеткой",
    "Error when trying to load the available live transcription languages" : "Ошибка при попытке загрузить доступные языки для онлайн-транскрипции",
    "Failed to enable live transcription" : "Ошибка при включении онлайн-транскрипции",
    "Failed to enable live translations" : "Ошибка при включении онлайн-перевода",
    "Failed to disable live translations" : "Ошибка при отключении онлайн-перевода",
    "Recording consent is required" : "Требуется согласие на запись",
    "This conversation is read-only" : "Это обсуждение доступно только для чтения",
    "Conversation not found or not joined" : "Обсуждение не найдено или к нему не присоединились",
    "Lobby is still active and you're not a moderator" : "Комната ожидания ещё активна и вы не являетесь модератором",
    "Connection failed" : "Сбой подключения",
    "Reload" : "Обновить",
    "{nickName} raised their hand." : "{nickName} поднял(а) руку.",
    "A participant raised their hand." : "Участник поднял руку.",
    "Collapse stripe" : "Свернуть ленту",
    "Expand stripe" : "Развернуть ленту",
    "Previous page of videos" : "Предыдущая страница с видео",
    "Next page of videos" : "Следующая страница с видео",
    "Connecting …" : "Соединение…",
    "Calling …" : "Вызов …",
    "Waiting for {user} to join the call" : "Ожидание подключения к вызову пользователя {user}",
    "Waiting for others to join the call …" : "Ожидание подключения к вызову остальных пользователей…",
    "You can invite others in the participant tab of the sidebar" : "Другие участники могут быть приглашены через боковую панель",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Вы можете пригласить других на вкладке участников боковой панели или поделиться этой ссылкой для приглашения!",
    "Share this link to invite others!" : "Используйте эту ссылку для приглашения других участников!",
    "Copy link" : "Копировать ссылку",
    "You are not allowed to enable audio" : "Вам не разрешено использовать аудио",
    "No audio. Click to select device" : "Нет аудио. Нажмите, чтобы выбрать устройство",
    "Mute audio" : "Отключить звук",
    "Mute audio (M)" : "Отключить звук (M)",
    "Unmute audio" : "Включить звук",
    "Unmute audio (M)" : "Включить звук (M)",
    "None" : "Не использовать",
    "Select a microphone" : "Выбрать микрофон",
    "Select a speaker" : "Выбрать динамик",
    "Microphone settings" : "Параметры микрофона",
    "Check devices" : "Проверить устройства",
    "Access to camera was denied" : "Доступ к камере запрещён",
    "Error while accessing camera: It is likely in use by another program" : "Ошибка при доступе к камере: Вероятно, она используется другой программой",
    "Error while accessing camera" : "Ошибка при доступе к камере",
    "You have been muted by a moderator" : "Ваш микрофон был отключен модератором",
    "Hide presenter video" : "Скрыть видео выступающего",
    "You are not allowed to enable video" : "Вам не разрешено использовать видео",
    "No video. Click to select device" : "Нет видео. Нажмите, чтобы выбрать устройство",
    "Disable video" : "Отключить видео",
    "Disable video (V)" : "Отключить видео (V)",
    "Enable video" : "Включить видео",
    "Enable video (V)" : "Включить видео (V)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "Разрешить видео - Ваше соединение будет прервано, когда разрешаете видео в первый раз",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Включение трансляции видео (V) - подключение будет кратковременно прервано при первом включении.",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Включение трансляции видео. Подключение будет кратковременно прервано при первом включении.",
    "Select a video device" : "Выбрать камеру",
    "Show presenter" : "показать выступающего",
    "You" : "Вы",
    "Mute" : "Отключить звук",
    "Muted" : "Звук отключен",
    "Show screen" : "Показать экран",
    "Stop following" : "Прекратить отслеживание",
    "Connection could not be established …" : "Не удалось установить соединение ...",
    "Connection was lost and could not be re-established …" : "Соединение было потеряно и не может быть восстановлено ...",
    "Connection could not be established. Trying again …" : "Не удалось установить соединение. Повторите попытку ...",
    "Connection lost. Trying to reconnect …" : "Соединение потеряно. Попытка повторного подключения ...",
    "Connection problems …" : "Проблемы с подключением ...",
    "Collapse" : "Свернуть",
    "Expand" : "Развернуть",
    "You need to be logged in to upload files" : "Для добавления файлов необходимо войти в систему",
    "Drop your files to upload" : "Для загрузки файлов, перетащите их сюда",
    "Conversation messages" : "Сообщения обсуждения",
    "Scroll to bottom" : "Прокрутить вниз",
    "Post message" : "Опубликовать сообщение",
    "Federated conversation" : "Федеративное обсуждение",
    "Public conversation" : "Открытое обсуждение",
    "Favorite" : "Избранное",
    "Banned users" : "Забаненные пользователи",
    "Manage the list of banned users in this conversation." : "Управляйте списком забаненных пользователей в этом обсуждении.",
    "Manage bans" : "Управлять банами",
    "No banned users" : "Нет забаненных пользователей",
    "Banned by:" : "Забанен:",
    "Date:" : "Дата:",
    "Note:" : "Примечание:",
    "Hide details" : "Скрыть подробные сведения",
    "Show details" : "Подробные сведения",
    "Unban" : "Разбанить",
    "You can change the title and the description in {linkstart}Calendar ↗{linkend}." : " Вы можете изменить название и описание в {linkstart}Календаре ↗{linkend}.",
    "Error while updating conversation name" : "Ошибка при изменении названия обсуждения",
    "Error while updating conversation description" : "Не удалось изменить описание обсуждения",
    "Enter a name for this conversation" : "Введите название обсуждения",
    "Edit conversation name" : "Изменить название обсуждения",
    "Edit conversation description" : "Изменить описание обсуждения",
    "Enter a description for this conversation" : "Задайте описание этого обсуждения",
    "Picture" : "Изображение",
    "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server." : "Следующие боты могут быть включены в этом обсуждении. Свяжитесь с вашей администрацией, чтобы установить больше ботов на этом сервере.",
    "No bots are installed on this server. Reach out to your administration to get bots installed on this server." : "Ни один бот не установлен на этом сервере. Свяжитесь с вашей администрацией, чтобы установить больше ботов на этом сервере.",
    "Disable" : "Отключить",
    "Enable" : "Включить",
    "The bot is not available anymore" : "Бот больше не доступен",
    "Breakout rooms" : "Комнаты обсуждения",
    "Manage breakout rooms" : "Управлять комнатами обсуждения",
    "Set up breakout rooms for this conversation" : "Настроить комнаты обсуждения для этого обсуждения",
    "Please select a valid PNG or JPG file" : "Выберите файл в формате .png или .jpg",
    "Choose your conversation picture" : "Выберите свое изображение для обсуждения ",
    "Choose" : "Выберите",
    "Error setting conversation picture" : "Ошибка при установке изображения для обсуждения",
    "Could not set the conversation picture: {error}" : "Не удалось установить изображение для обсуждения: {error}",
    "Error cropping conversation picture" : "Не удалось обрезать изображение для обсуждения",
    "Error removing conversation picture" : "Ошибка удаления изображения из обсуждения",
    "Set emoji as conversation picture" : "Установить эмодзи в качестве изображения обсуждения",
    "Set background color for conversation picture" : "Установить цвет фона для изображения обсуждения",
    "Upload conversation picture" : "Загрузить изображение обсуждения",
    "Choose conversation picture from files" : "Выбрать аватар обсуждения из Файлов",
    "Remove conversation picture" : "Удалить изображение обсуждения",
    "The file must be a PNG or JPG" : "Файл должен быть в формате PNG или JPG",
    "Set picture" : "Установить изображение",
    "Default permissions modified for {conversationName}" : "Разрешения по умолчанию изменены для {conversationName}",
    "Could not modify default permissions for {conversationName}" : "Не удалось изменить разрешения по умолчанию для {conversationName}",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Редактирование разрешений по умолчанию для участников этого обсуждения. Эти настройки не влияют на модераторов.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Каждый раз, когда разрешения изменяются в этом разделе, пользовательские разрешения, ранее назначенные отдельным участникам, будут потеряны.",
    "All permissions" : "Все разрешения",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "Участники полноправны начинать вызов, присоединяться к вызову, включать аудио- и видеосвязь и транслировать экран.",
    "Restricted" : "Ограниченный",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Участники могут присоединиться к звонкам, но не могут включить аудио- и видеосвязь, а также трансляцию экрана, пока модератор вручную не предоставит им соответствующие разрешения.",
    "Advanced permissions" : "Дополнительные разрешения",
    "Edit permissions" : "Разрешения на редактирование",
    "Conversation settings" : "Настройки обсуждения",
    "Basic Info" : "Базовая информация",
    "Personal" : "Личное",
    "Moderation" : "Модерация",
    "Setup overview" : "Обзор настроек",
    "Live transcription" : "Онлайн-транскрипция",
    "Live transcriptions app is not installed" : "Приложение для онлайн-транскрипции не установлно",
    "Enable live transcription" : "Включить онлайн-транскрипцию",
    "Breakout Rooms" : "Комнаты обсуждения",
    "Matterbridge" : "Matterbridge",
    "Bots" : "Боты",
    "Danger zone" : "Опасная зона",
    "Archive conversation" : "Архивировать обсуждение",
    "Archived conversations are hidden from the conversation list by default. However, they will still appear when you search for the conversation name or access a list of archived conversations." : "Архивированные обсуждения скрыты из списка обсуждений по умолчанию. Однако, они всё ещё доступны при поиске обсуждения по имени или при открытии списка архивированных обсуждений",
    "Do you really want to leave \"{displayName}\"?" : "Действительно покинуть «{displayName}»?",
    "You can archive this conversation instead." : "Вместо этого Вы можете архивировать обсуждение.",
    "Leave conversation" : "Покинуть обсуждение",
    "You need to promote a new moderator before you can leave the conversation" : "Вам нужно назначить нового модератора перед тем, как покинуть обсуждение",
    "Delete conversation" : "Удалить обсуждение",
    "Do you really want to delete \"{displayName}\"?" : "Действительно удалить «{displayName}»?",
    "Error while deleting conversation" : "Ошибка при удалении обсуждения",
    "Delete all chat messages" : "Удалить все сообщения",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Действительно удалить все сообщения в «{displayName}\"»?",
    "Error while clearing chat history" : "Не удалось очистить историю сообщений",
    "Be careful, these actions cannot be undone." : "Будьте осторожны, эти действия нельзя отменить.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Если обсуждение было покинуто, для повторного присоединения требуется приглашение. К открытым обсуждениям возможно присоединиться в любое время.",
    "Permanently delete this conversation." : "Безвозвратно удалить это обсуждениe.",
    "Delete chat messages" : "Удалить сообщения",
    "Permanently delete all the messages in this conversation." : "Безвозвратно удалить все сообщения в этом обсуждении.",
    "_%n hour_::_%n hours_" : ["%n час","%n часа","%n часов","%n часа"],
    "_%n day_::_%n days_" : ["%n день","%n дня","%n дней","%n дня"],
    "_%n week_::_%n weeks_" : ["%n неделя","%n недели","%n недель","%n недели"],
    "Custom expiration time" : "Установить срок жизни",
    "Message expiration disabled" : "Срок жизни сообщений отключен",
    "Message expiration set: {duration}" : "Срок жизни сообщений установлен: {duration}",
    "Error when trying to set message expiration" : "Ошибка при попытке установить срок жизни сообщений",
    "Message expiration" : "Срок жизни сообщений",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Сообщения чата могут быть удалены по истечении определенного времени. Примечание: Файлы, переданные в чате, не будут удалены для владельца, но больше не будут доступны в обсуждении.",
    "Set message expiration" : "Установить срок жизни сообщений",
    "Current message expiration" : "Текущий срок жизни сообщений",
    "Password copied to clipboard" : "Пароль скопирован в буфер обмена",
    "Password could not be copied" : "Не удалось скопировать пароль",
    "Guest access" : "Гостевой доступ",
    "Breakout rooms are not allowed in public conversations." : "Комнаты обсуждения недоступны в открытых обсуждениях",
    "Allow guests to join this conversation via link" : "Разрешить гостям присоединяться к обсуждению по ссылке",
    "Password protection" : "Защита паролем",
    "This conversation is password-protected. Guests need password to join" : "Это обсуждение защищено паролем. Гостям требуется пароль, чтобы присоединиться",
    "Password protection is needed for public conversations" : "Защита паролем требуется для публичных обсуждений",
    "Set a password" : "Задать пароль",
    "Change password" : "Сменить пароль",
    "Enter new password" : "Введите новый пароль",
    "Save password" : "Сохранить пароль",
    "Copy password" : "Копировать пароль",
    "Guests are allowed to join this conversation via link" : "Гости могут присоединяться к обсуждению по ссылке",
    "Guests are not allowed to join this conversation" : "Гостям не разрешено присоединяться к этому обсуждению",
    "Resend invitations" : "Повторно отправить приглашения",
    "This conversation is open to both registered users and users created with the Guests app" : "Это обсуждение открыто для зарегистрированных пользователей и пользователей, созданных через приложение «Гости»",
    "This conversation is open to registered users" : "Обсуждение открыто для зарегистрированных пользователей",
    "This conversation is limited to the current participants" : "Обсуждение ограничено текущими участниками",
    "You opened the conversation to both registered users and users created with the Guests app" : "Вы открыли обсуждение для зарегистрированных пользователей и пользователей, созданных через приложение «Гости»",
    "Error occurred when opening or limiting the conversation" : "Не удалось открыть или ограничить доступ к обсуждению",
    "Open conversation to registered users, showing it in search results" : "Это обсуждение будет показано в результатах поиска для зарегистрированных пользователей",
    "Also open to users created with the Guests app" : "Также открыть для пользователей, созданных через приложение «Гости»",
    "Open conversation" : "Открытое обсуждение",
    "Set language spoken in calls" : "Установить язык, используемый при вызове",
    "Languages could not be loaded" : "Языки не могут быть загружены",
    "Loading languages …" : "Загрузка языков …",
    "Invalid language" : "Недопустимый язык",
    "Default language (English)" : "Язык по умолчанию (English)",
    "Default live transcription language set" : "Язык для онлайн-транскрипции по умолчанию установлен",
    "Live transcription language set: {languageName}" : "Язык для онлайн-транскрипции установлен: {languageName}",
    "Error when trying to set live transcription language" : "Ошибка при попытке установить язык для онлайн-транскрипции",
    "Start time: {date}" : "Время начала: {date}",
    "Start time has been updated" : "Время начала изменено",
    "Error occurred while updating start time" : "Не удалось изменить время начала",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "Включение лобби отключит всех, кроме модераторов, от текущего вызова.",
    "Enable lobby, restricting the conversation to moderators" : "Включить лобби, ограничив доступ к обсуждению только для модераторов",
    "Meeting start time" : "Время начала встречи",
    "Start time (optional)" : "Время начала (необязательно)",
    "Import email participants" : "Импортировать участников по адресам эл. почты",
    "You can import a list of email participants from a CSV file." : "Вы можете импортировать участников по адресам эл. почты из CSV файла.",
    "Poll drafts" : "Черновики опросов",
    "Browse poll drafts" : "Просмотреть черновики опросов",
    "Error occurred when locking the conversation" : "Не удалось заблокировать обсуждение",
    "Error occurred when unlocking the conversation" : "Не удалось разблокировать обсуждение",
    "Lock conversation" : "Заблокировать обсуждение",
    "This will also terminate the ongoing call." : "Это также прервет текущий разговор.",
    "Lock the conversation to prevent anyone to post messages or start calls" : "Заблокировать обсуждение, чтобы запретить кому-либо отправлять сообщения или начинать вызов",
    "Edit" : "Редактировать",
    "More information" : "Дополнительные сведения",
    "Delete" : "Удалить",
    "Add new bridged channel to current conversation" : "Добавить к обсуждению новый канал обмена сообщениями",
    "unknown state" : "неизвестное состояние",
    "running" : "запущено",
    "not running, check Matterbridge log" : "не запущено, проверьте журнал Matterbridge",
    "not running" : "не запущено",
    "Bridge saved" : "Параметры обмена сохранены",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "Matterbridge позволяет настроить обмен сообщеними с различными службами моментальных сообщений.",
    "More info on Matterbridge" : "Дополнительные сведения о Matterbridge",
    "Messaging systems" : "Системы обмена сообщениями",
    "Enable bridge" : "Включить обмен собщениями",
    "Show Matterbridge log" : "Открыть журнал Matterbridge",
    "Log content" : "Записи журнала",
    "Only moderators are allowed to mention @all" : "Только модераторы могут упоминать всех (@all)",
    "All participants are allowed to mention @all" : "Все участники могут упоминать всех (@all)",
    "Participants are now allowed to mention @all." : "Теперь участники могут упоминать всех (@all)",
    "Mentioning @all has been limited to moderators." : " Упоминание всех (@all) было ограничено только для модераторов",
    "Allow participants to mention @all" : "Разрешить участникам упоминать всех (@all)",
    "Mention permissions" : "Упоминание разрешений",
    "Notifications" : "Уведомления",
    "Notify about calls in this conversation" : "Уведомлять о вызовах в этом обсуждении",
    "Important conversation" : "Важное обсуждение",
    "\"Do not disturb\" user status is ignored for important conversations" : "Статус «Не беспокоить» игнорируется для важных обсуждений",
    "Sensitive conversation" : "Конфиденциальное обсуждение",
    "Message preview will be disabled in conversation list and notifications" : "Предварительный просмотр сообщений будет отключен в списке обсуждений и уведомлениях",
    "Recording consent is required for calls in this conversation" : "Согласие на запись требуется для вызовов в этом обсуждении",
    "Recording consent is not required for calls in this conversation" : "Согласие на запись не требуется для вызовов в этом обсуждении",
    "Recording consent requirement was updated" : "Требование на согласие с записью вызова было изменено",
    "Error occurred while updating recording consent" : "Произошла ошибка при изменении согласия на запись вызова",
    "Recording Consent" : "Согласие на запись вызова",
    "Recording consent cannot be changed once a call or breakout session has started." : "Согласие на запись не может быть изменено после начала вызова или сессии в комнатах обсуждения.",
    "Require recording consent before joining call in this conversation" : "Требовать согласие на запись перед присоединением к вызову в этом обсуждении",
    "Recording consent is required for all calls" : "Согласие на запись требуется для всех вызовов",
    "SIP dial-in is now possible without PIN requirement" : "SIP-вызовы теперь возможны без запроса PIN-кода",
    "SIP dial-in is now enabled" : "Входящие вызовы с использованием протокола SIP включены",
    "SIP dial-in is now disabled" : "Входящие вызовы с использованием протокола SIP отключены",
    "Error occurred when enabling SIP dial-in" : "Не удалось включить входящие SIP-вызовы",
    "Error occurred when disabling SIP dial-in" : "Не удалось отключить входящие SIP-вызовы",
    "Phone and SIP dial-in" : "Телефон и SIP-вызовы",
    "Enable phone and SIP dial-in" : "Включить телефон и входящие SIP-вызовы",
    "Allow to dial-in without a PIN" : "Разрешить набор номера без PIN-кода",
    "Ongoing" : "Текущий",
    "{dayPrefix} {dateTime}" : "{dayPrefix} {dateTime}",
    "_%n person accepted_::_%n people accepted_" : ["%n человек принял","%n человека приняли","%n человек приняли","%n человек приняли"],
    "_%n person declined_::_%n people declined_" : ["%n человек отклонил","%n человека отклонили","%n человек отклонили","%n человек отклонили"],
    "_and %n other attachment_::_and %n other attachments_" : ["и ещё %n вложение","и ещё %n вложения","и ещё %n вложений","и ещё %n вложений"],
    "With {displayName}" : "С {displayName}",
    "In {conversation}" : "В {conversation}",
    "View attachment" : "Просмотреть вложение",
    "Join" : "Присоединиться",
    "View conversation" : "Просмотреть обсуждение",
    "View event on Calendar" : "Просмотреть событие в Календаре",
    "Error while creating the conversation" : "Не удалось создать обсуждение",
    "Hello, {displayName}" : "Привет, {displayName}",
    "Start meeting now" : "Начать встречу сейчас",
    "Give your meeting a title" : "Дайте заголовок вашей встрече",
    "Create and copy link" : "Создать и скопировать ссылку",
    "Create a new conversation" : "Создать новое обсуждение",
    "Join open conversations" : "Присоединиться к открытым обсуждениям",
    "Call a phone number" : "Вызвать номер телефона",
    "Scroll backward" : "Прокрутить назад",
    "Scroll forward" : "Прокрутить вперед",
    "Schedule meetings" : "Запланировать встречи",
    "You don't have any upcoming meetings" : "У вас нет предстоящих встреч",
    "Open calendar" : "Открыть Календарь",
    "Unread mentions" : "Непрочитанные упоминания",
    "Messages where you were mentioned will show up here. You can mention people by typing @ followed by their name" : "Сообщения с вашим упоминанием появятся здесь. Вы также можете упоминать людей, печатая \"@\" и имя пользователя",
    "Upcoming reminders" : "Предстоящие напоминания",
    "Message reminders" : "Напоминания о сообщениях",
    "Set a reminder on a message to be notified" : "Установите напоминание о сообщении, чтобы получать уведомления",
    "Start a group conversation" : "Начать групповое обсуждение",
    "Create conversation" : "Создать обсуждение",
    "Enter your name" : "Введите ваше имя",
    "Submit name and join" : "Укажите имя и присоединитесь",
    "Do you already have an account?" : "У вас уже есть учетная запись?",
    "Log in" : "Войти",
    "Error while verifying uploaded file" : "Ошибка при проверке загруженного файла",
    "Uploaded file is verified" : "Загруженный файл проверен",
    "Content format is comma-separated values (CSV):<br/>- Header line is required and must match <samp>\"name\",\"email\"</samp> or just <samp>\"email\"</samp><br/>- One entry per line (e.g. <samp>\"John Doe\",\"john@example.tld\"</samp>)" : "Содержимое в формате «сomma-separated values» (CSV):<br/>- Строка заголовка обязательна и должна совпадать с <samp>\"name\",\"email\"</samp> или только <samp>\"email\"</samp><br/>- Один участник на одну линию (например, <samp>\"John Doe\",\"john@example.tld\"</samp>)",
    "Participants added successfully" : "Участники успешно добавлены",
    "Error while adding participants" : "Ошибка при добавлении участников",
    "Import a file" : "Импортировать файл",
    "Browse" : "Выбрать",
    "Verifying uploaded file …" : "Проверка загруженного файла …",
    "This might take a moment" : "Это может занять некоторое время",
    "Send invitations" : "Отправить приглашения",
    "_%n invalid email_::_%n invalid emails_" : ["%n некорректный адрес эл. почты","%n некорректных адреса эл. почты","%n некорректных адресов эл. почты","%n некорректных адресов эл. почты"],
    "_%n email is already imported or a duplicate_::_%n emails are already imported or duplicates_" : ["%n адрес эл. почты уже добавлен или дублируется","%n адреса эл. почты уже добавлены или дублируются","%n адресов эл. почты уже добавлены или дублируются","%n адресов эл. почты уже добавлены или дублируются"],
    "_%n invitation can be sent_::_%n invitations can be sent_" : ["%n приглашение может быть отправлено","%n приглашения может быть отправлено","%n приглашений может быть отправлено","%n приглашений может быть отправлено"],
    "An error occurred while calling a phone number" : "Произошла ошибка при вызове номера телефона",
    "Phone number could not be called: {error}" : "Номер телефона не может быть вызван: {error}",
    "Phone number could not be called" : "Номер телефона не может быть вызван",
    "Search participants or phone numbers" : "Искать участников или номера телефона",
    "Creating the conversation …" : "Создание обсуждения …",
    "Mark as read" : "Пометить прочитанным",
    "Mark as unread" : "Пометить непрочитанным",
    "Remove from favorites" : "Удалить из избранного",
    "Add to favorites" : "Добавить в избранное",
    "Unarchive conversation" : "Разархивировать обсуждение",
    "Ignore \"Do not disturb\"" : "Игнорировать \"Не беспокоить\"",
    "You need to promote a new moderator before you can leave the conversation." : "Вам нужно назначить нового модератора перед тем, как покинуть обсуждение.",
    "Conversation actions" : "Действия для обсуждения",
    "Notify about calls" : "Уведомлять о вызовах",
    "Hide message text" : "Скрыть текст сообщений",
    "Pending invitations" : "Ожидающие приглашения",
    "Join conversations from other servers" : "Присоединитесь к обсуждениям на удалённых серверах",
    "From {user} at {remoteServer}" : "От {user} с {remoteServer}",
    "Decline invitation" : "Отклонить приглашение",
    "Accept invitation" : "Принять приглашение",
    "No pending invitations" : "Нет ожидающих приглашений",
    "Home" : "Домашняя страница",
    "Unread" : "Непрочитанное",
    "Mentions" : "Упоминания",
    "Meetings" : "Встречи",
    "Sort conversations" : "Сортировать обсуждения",
    "By recent activity" : "По недавней активности",
    "Alphabetically" : "В алфавитном порядке",
    "Do not group by type" : "Не группировать",
    "Show private ones first" : "Показать сначала частные",
    "Show group ones first" : "Показать сначала групповые",
    "No followed threads" : "Нет отслеживаемых тем",
    "No matches found" : "Соответствий не найдено",
    "No conversations found" : "Не найдено ни одного обсуждения",
    "You have no archived conversations." : "У Вас нет архивированных обсуждений.",
    "Subscribe to an existing thread or start your own." : "Начните отслеживать существующую тему или создайте новую.",
    "You have no unread mentions." : "У Вас нет непрочитанных упоминаний или личных сообщений.",
    "You have no unread messages." : "У Вас нет непрочитанных сообщений.",
    "An error occurred while performing the search" : "Не удалось выполнить поиск",
    "Conversation list" : "Список обсуждений",
    "Filter conversations by" : "Фильтровать обсуждения",
    "Unread messages" : "Непрочитанные сообщения",
    "Meeting conversations" : "Обсуждения - встречи",
    "Clear filters" : "Сбросить фильтры",
    "New personal note" : "Новая личная заметка",
    "SIP backend is not installed" : "SIP сервер не установлен",
    "Back to conversations" : "Обратно к обсуждениям",
    "Archived conversations" : "Архивированные обсуждения",
    "Threads" : "Темы",
    "Clear filter" : "Сбросить фильтр",
    "Show more threads" : "Показать больше тем",
    "App settings" : "Настройки приложения",
    "Users" : "Пользователи",
    "Groups" : "Группы",
    "Teams" : "Команды",
    "Federated users" : "Федеративные пользователи",
    "New private conversation" : "Новое частное обсуждение",
    "Other sources" : "Другие источники",
    "Open conversations" : "Открытые обсуждения",
    "No search results" : "Ничего не найдено",
    "Users, groups and teams" : "Пользователи, группы и команды",
    "Users and groups" : "Пользователи и группы",
    "Users and teams" : "Пользователи и команды",
    "Groups and teams" : "Группы и команды",
    "New group conversation" : "Новое групповое обсуждение",
    "The meeting will start soon" : "Встреча скоро начнётся",
    "This meeting is scheduled for {startTime}" : "Начало встречи запланировано на {startTime}",
    "You are currently waiting in the lobby" : "В данный момент вы ожидаете в лобби",
    "Enable noise suppression" : "Включить подавление шума",
    "Reduce background noises for better voice quality" : "Уменьшить фоновый шум для лучшего качества голоса",
    "Enable echo cancellation" : "Включить подавление эха",
    "Minimize echo effect from own surrounding" : "Уменьшить эффект эха от собственного окружения",
    "Enable auto gain control" : "Включить авторегулировку громкости",
    "Dynamically adjust microphone volume for consistent level" : "Динамически подстраивать громкость микрофона для стабильного уровня",
    "Select microphone" : "Выберите микрофон",
    "No microphone available" : "Нет ни одного доступного микрофона",
    "Select speaker" : "Выберите динамик",
    "No speaker available" : "Нет ни одного доступного динамика",
    "Select camera" : "Выберите камеру",
    "No camera available" : "Нет ни одной доступной камеры",
    "Select a device" : "Выберите устройство",
    "Playing …" : "Воспроизводится …",
    "Test speakers" : "Проверить динамики",
    "Test" : "Проверить",
    "Devices" : "Устройства",
    "Backgrounds" : "Фоны",
    "No audio" : "Без звука",
    "No camera" : "Камера отсуствует",
    "Display video as you will see it (mirrored)" : "Показать видео как Вы его видите (зеркально)",
    "Display video as others will see it" : "Показать видео как другие его видят",
    "Calls are not supported in your browser" : "Ваш браузер не поддерживает вызовы",
    "Access to microphone is only possible with HTTPS" : "Доступ к микрофону разрешён только при использовании протокола HTTPS",
    "Access to microphone was denied" : "Доступ к микрофону запрещён",
    "Error while accessing microphone" : "Не удалось получить доступ к микрофону",
    "Access to camera is only possible with HTTPS" : "Доступ к камере разрешён только при использовании протокола HTTPS",
    "The call is being recorded." : "Вызов записывается.",
    "The call might be recorded." : "Вызов может быть записан.",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "Запись может включать ваш голос, видео с камеры и трансляцию экрана. Прежде чем присоединиться к вызову, требуется ваше согласие.",
    "Give consent to the recording of this call" : "Дать согласие на запись этого вызова",
    "Show more info" : "Показать больше",
    "Audio is not available" : "Аудио недоступно",
    "Video is not available" : "Видео недоступно",
    "Start recording immediately with the call" : "Начать запись одновременно с вызовом",
    "Recording backend is not installed" : "Сервер записи вызовов не установлен",
    "Notify all participants about this call" : "Уведомить всех участников о начале вызова",
    "Apply settings" : "Применить настройки",
    "Select virtual office background" : "Выбрать виртуальный фон офиса",
    "Select virtual home background" : "Выбрать виртуальный фон дома",
    "Select virtual abstract background" : "Выбрать абстрактный виртуальный фон",
    "Select virtual beach background" : "Выбрать виртуальный фон пляжа",
    "Select virtual park background" : "Выбрать виртуальный фон парка",
    "Select virtual theater background" : "Выбрать виртуальный фон театра",
    "Select virtual library background" : "Выбрать виртуальный фон библиотеки",
    "Select virtual space station background" : "Выбрать виртуальный фон космической станции",
    "Error while uploading the file" : "Ошибка при загрузке файла",
    "Select a file" : "Выберите файл",
    "Invalid path selected" : "Указан некорректный путь",
    "Select virtual background from file {fileName}" : "Выбрать виртуальный фон из файла {fileName}",
    "Blur" : "Размытие",
    "Upload" : "Отправить",
    "Files" : "Файлы",
    "(editing)" : "(редактируется)",
    "(edited)" : "(изменено)",
    "The message has expired or has been deleted" : "Срок жизни сообщения истёк или оно было удалено",
    "Cancel quote" : "Отменить квоту",
    "24 hours" : "24 часа",
    "7 days" : "7 дней",
    "30 days" : "30 дней",
    "Until unpin" : "До открепления",
    "Clear reminder – {timeLocale}" : "Очистить напоминание – {timeLocale}",
    "Edited by {actor}" : "Изменено {actor}",
    "Pinned by you" : "Закреплено Вами",
    "Pinned by {actor}" : "Закреплено {actor}",
    "Until {absoluteDate}" : "До {absoluteDate}",
    "Message text copied to clipboard" : "Сообщение скопировано в буфер обмена",
    "Message text could not be copied" : "Не удалось скопировать текст сообщения",
    "Message forwarded to \"Note to self\"" : "Сообщение перенаправлено в «Личные заметки»",
    "Error while forwarding message to \"Note to self\"" : "Ошибка при пересылке сообщения в «Личные заметки»",
    "A reminder was successfully removed" : "Напоминание было успешно удалено",
    "Error occurred when removing a reminder" : "Произошла ошибка при удалении напоминания",
    "A reminder was successfully set at {datetime}" : "Напоминание было успешно установлено на {datetime}",
    "Error occurred when creating a reminder" : "Произошла ошибка при создании напоминания",
    "Add a reaction to this message" : "Отреагировать на это сообщение",
    "Reply" : "Ответить",
    "More actions" : "Больше действий",
    "Set reminder" : "Установить напоминание",
    "Pin message" : "Закрепить сообщение",
    "Unpin message" : "Открепить сообщение",
    "Reply privately" : "Ответить личным сообщением",
    "Edit message" : "Редактировать сообщение",
    "Copy message" : "Копировать сообщение",
    "Copy message link" : "Скопировать ссылку на сообщение",
    "Go to file" : "Перейти к файлу",
    "Download file" : "Скачать файл",
    "Go to thread" : "Перейти в тему",
    "Edit thread details" : "Изменить детали темы",
    "Forward message" : "Переслать сообщение",
    "Translate" : "Перевести",
    "Set custom reminder" : "Установить особое напоминание",
    "Keep pinned for" : "Держать закрепленным:",
    "Set custom period" : "Установить особый период",
    "Close reactions menu" : "Закрыть меню реакций",
    "React with {emoji}" : "Отреагируйте с {emoji}",
    "React with another emoji" : "Отреагировать другим эмодзи",
    "Choose a conversation to forward the selected message." : "Выберите обсуждение для пересылки выбранного сообщения.",
    "Error while forwarding message" : "Не удалось переслать сообщение",
    "The message has been forwarded to {selectedConversationName}" : "Сообщение переслано в {selectedConversationName}",
    "Dismiss" : "Отклонить",
    "Go to conversation" : "Перейти в обсуждение",
    "Detect language" : "Определить язык",
    "The message could not be translated" : "Сообщение не может быть переведено",
    "Translation copied to clipboard" : "Перевод скопирован в буфер обмена",
    "Translation could not be copied" : "Не удалось скопировать перевод",
    "Translate message" : "Перевести сообщение",
    "Source language to translate from" : "Исходный язык для перевода с",
    "Translate from" : "Перевод с",
    "Target language to translate into" : "Целевой язык для перевода на",
    "Translate to" : "Перевести на",
    "Translating" : "Идет перевод",
    "This translation is AI generated and may contain mistakes." : "Перевод сгенерирован при помощи AI и может быть неточным",
    "Copy translated text" : "Копировать переведенный текст",
    "Error when scheduling the message" : "Ошибка при планировании сообщения",
    "Reschedule" : "Перенести",
    "Send now" : "Отправить сейчас",
    "Choose a time" : "Выберите время",
    "Send at custom time" : "Отправить в указанное время",
    "Will be sent without notification" : "Будет отправлено без уведомления",
    "Message read by everyone who shares their reading status" : "Сообщение прочитано всеми пользователями, включившими отчёт о прочтении",
    "Message sent" : "Сообщение отправлено",
    "Sent without notification" : "Отправлено без уведомления",
    "Deleting message" : "Сообщение удаляется",
    "Message deleted successfully, but a bot or Matterbridge is configured and the message might already be distributed to other services" : "Сообщение успешно удалено, но настроен бот или Matterbridge, и сообщение может быть уже распространено на другие сервисы",
    "Message deleted successfully" : "Сообщение успешно удалено",
    "Message could not be deleted because it is too old" : "Сообщение не может быть удалено, т.к. оно было отправлено давно",
    "Only normal chat messages can be deleted" : "Только обычные сообщения могут быть удалены",
    "An error occurred while deleting the message" : "Не удалось удалить сообщение",
    "Pinned" : "Закреплено",
    "Your browser does not support playing audio files" : "Ваш браузер не поддерживает воспроизведение звуковых файлов",
    "Contact" : "Контакт",
    "{stack} in {board}" : "«{stack}» с доски «{board}»",
    "Deck Card" : "Карточка",
    "Remove {fileName}" : "Удалить {fileName}",
    "Open this location in OpenStreetMap" : "Открыть местоположение в OpenStreetMap",
    "_%n reply_::_%n replies_" : ["%n ответ","%n ответа","%n ответов","%n ответов"],
    "Sending message" : "Сообщение отправляется",
    "Failed to send the message. Click to try again" : "Не удалось отправить сообщение; нажмите, чтобы попробовать ещё раз",
    "Not enough free space to upload file" : "Недостаточно свободного места для передачи файла на сервер",
    "You cannot send messages to this conversation at the moment" : "Сейчас вы не можете отправлять сообщения в это обсуждение",
    "Could not update the message" : "Не удалось обновить сообщение",
    "Reply to thread \"{threadTitle}\"" : "Ответить в теме «{threadTitle}»",
    "_You voted • %n vote_::_You voted • %n votes_" : ["Вы проголосовали • %n голос","Вы проголосовали • %n голоса","Вы проголосовали • %n голосов","Вы проголосовали • %n голосов"],
    "You voted" : "Вы проголосовали",
    "_Click to vote • %n vote_::_Click to vote • %n votes_" : ["Нажмите для голосования • %n голос","Нажмите для голосования • %n голоса","Нажмите для голосования • %n голосов","Нажмите для голосования • %n голосов"],
    "Click to vote" : "Нажмите для голосования",
    "_Poll draft • %n option_::_Poll draft • %n options_" : ["Черновик опроса • %n вариант","Черновик опроса • %n варианта","Черновик опроса • %n вариантов","Черновик опроса • %n вариантов"],
    "_%n vote_::_%n votes_" : ["%n голос","%n голоса","%n голосов","%n голосов"],
    "Edit poll draft" : "Изменить черновик опроса",
    "Delete poll draft" : "Удалить черновик опроса",
    "Open poll" : "Открытый опрос",
    "Closed poll" : "Закрытый опрос",
    "See results" : "Посмотреть результаты",
    "Reactions" : "Реакции",
    "No permission to post reactions in this conversation" : "Нет разрешения на публикацию реакций в этом обсуждении",
    "and {participant}" : "и {participant}",
    "_and %n other participant_::_and %n other participants_" : ["и ещё %n участник","и ещё %n участника","и ещё %n участников","и ещё %n участников"],
    "Show all reactions" : "Показать все реакции",
    "Add more reactions" : "Добавить больше реакций",
    "Show or collapse system messages" : "Показать или скрыть системные сообщения",
    "No messages" : "Нет ни одного сообщения",
    "All messages have expired or have been deleted." : "Срок жизни сообщений истек или они были удалены.",
    "Generate summary with AI" : "Сгенерировать резюме с ИИ",
    "{author} (pinned by you)" : "{author} (закреплено Вами)",
    "{author} (pinned by {actor})" : "{author} (закреплено {actor})",
    "Unpin" : "Открепить",
    "Cancel search" : "Отменить поиск",
    "Add a phone number" : "Добавить номер телефона",
    "Error: A password is required to create the conversation." : "Ошибка: для создания обсуждения требуется пароль.",
    "All set, the conversation \"{conversationName}\" was created." : "Всё готово, обсуждение \"{conversationName}\" создано.",
    "Create a new group conversation" : "Создать новое групповое обсуждение",
    "Add participants" : "Добавить участников",
    "Maximum length exceeded ({maxlength} characters)" : "Максимальная длина превышена ({maxlength} символов)",
    "Conversation type" : "Тип обсуждения",
    "Conversation visibility" : "Видимость обсуждения",
    "Allow guests to join via link" : "Разрешить гостям присоединяться по ссылке",
    "Enter password" : "Введите пароль",
    "This conversation has been locked" : "Это обсуждение заблокировано",
    "No permission to post messages in this conversation" : "Отсутствует разрешение на публикацию сообщений в этом обсуждении",
    "Joining conversation …" : "Подключение к обсуждению…",
    "Write a message without notification" : "Напишите сообщение без уведомления",
    "Create a thread silently" : "Создать тему тихо",
    "Create a thread" : "Создать тему",
    "Send message silently" : "Отправить сообщение без звука",
    "Send message" : "Отправить сообщение",
    "Send without notification" : "Отправить без уведомления",
    "The participant will not be notified about new messages" : "Участник не получит уведомление о новых сообщениях",
    "Participants will not be notified about new messages" : "Участники не получат уведомлений о новых сообщениях",
    "Message will be sent {datetimeString}" : "Сообщение будет отправлено {datetimeString}",
    "Thread title is required" : "Заголовок темы обязателен",
    "Message text is required" : "Требуется текстовое сообщение",
    "The message could not be edited" : "Сообщение не может быть изменено",
    "File to share" : "Поделиться файлом",
    "File upload is not available in this conversation" : "Загрузка файлов недоступна для этого обсуждения",
    "Message was successfully scheduled" : "Сообщение успешно запланировано",
    "Add emoji" : "Добавить эмодзи",
    "Adding a mention will only notify users who did not read the message." : "Добавление упоминания уведомит только тех пользователей, кто ещё не прочитал сообщение.",
    "Thread title" : "Заголовок темы",
    "Send later" : "Отправить позже",
    "Show scheduled messages" : "Показать запланированные сообщения",
    "Cancel editing" : "Отменить редактирование",
    "Schedule message" : "Запланировать сообщение",
    "{user} is out of office and might not respond." : "{user} вне офиса и может не ответить.",
    "Absence period: {startDate} - {endDate}" : "Период отсутствия: {startDate} - {endDate}",
    "Replacement:" : "Замена:",
    "Share from {nextcloud}" : "Опубликовать из {nextcloud}",
    "Share from Files" : "Опубликовать из приложения «Файлы»",
    "Share files to the conversation" : "Поделиться файлами в обсуждении",
    "Upload from device" : "Загрузить с устройства",
    "Create new poll" : "Создать новый опрос",
    "Smart picker" : "Умный подборщик",
    "Record voice message" : "Записать голосовое сообщение",
    "End recording and send" : "Завершить запись и отправить",
    "Dismiss recording" : "Отменить запись",
    "Access to the microphone was denied" : "Не удалось получить доступ к микрофону",
    "Microphone either not available or disabled in settings" : "Микрофон недоступен или отключен",
    "Error while recording audio" : "Не удалось записать звук",
    "Voice message {time} ({conversation})" : "Голосовое сообщение {time} ({conversation})",
    "Generating summary of unread messages …" : "Резюме непрочитанных сообщений генерируется …",
    "Summary is AI generated and might contain mistakes" : "Резюме сгенерировано при помощи AI и может быть неточным",
    "Error occurred during a summary generation" : "Произошла ошибка при генерировании резюме",
    "New file" : "Новый файл",
    "Blank" : "Пустой",
    "Error while creating file" : "Не удалось создать файл",
    "Create and share a new file" : "Создайте и поделитесь новым файлом",
    "Name of the new file" : "Название нового файла",
    "Create file" : "Создать файл",
    "Someone is typing …" : "Кто-то печатает …",
    "{user1} is typing …" : "{user1} печатает …",
    "{user1} and {user2} are typing …" : "{user1} и {user2} печатают …",
    "{user1}, {user2} and {user3} are typing …" : "{user1}, {user2} и {user3} печатают …",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}, {user2}, {user3} и еще %n другой пользователь печатают …","{user1}, {user2}, {user3} и еще %n других пользователя печатают …","{user1}, {user2}, {user3} и еще %n других пользователей печатают …","{user1}, {user2}, {user3} и еще %n других пользователей печатают …"],
    "Add more files" : "Добавить файлы",
    "Send" : "Отправить",
    "In this conversation <strong>{user}</strong> can:" : "В этом обсуждении <strong>{user}</strong> может:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Изменить разрешения по умолчанию для участников <strong>{conversationName}</strong>",
    "Start a call" : "Начать вызов",
    "Skip the lobby" : "Пропустить лобби",
    "Can post messages" : "Отправлять сообщения",
    "Can post messages and reactions" : "Отправлять сообщения и реакции",
    "Can add reactions" : "Добавлять реакции",
    "Enable the microphone" : "Включить микрофон",
    "Enable the camera" : "Включить камеру",
    "Share the screen" : "Поделиться экраном",
    "Update permissions" : "Обновление разрешений",
    "Updating permissions" : "Обновление разрешений",
    "No poll drafts" : "Нет черновиков опросов",
    "There is no poll drafts yet saved for this conversation" : "Для этого обсуждения пока не сохранено ни одного черновика опроса",
    "Create poll in {name}" : "Создать опрос в {name}",
    "Create poll" : "Создать опрос",
    "Error while importing poll" : "Ошибка при импорте опроса",
    "Question" : "Вопрос",
    "Ask a question" : "Задать вопрос",
    "Import draft from file" : "Импортировать черновик из файла",
    "Answers" : "Ответы",
    "Answer {option}" : "Ответ «{option}»",
    "Delete poll option" : "Удалить вариант опроса",
    "Add answer" : "Добавить ответ",
    "Settings" : "Настройки",
    "Anonymous poll" : "Анонимный опрос",
    "Multiple answers" : "Множество ответов",
    "Save as draft" : "Сохранить как черновик",
    "Export draft to file" : "Экспортировать черновик в файл",
    "_Final results • %n vote_::_Final results • %n votes_" : ["Результаты опроса • %n голос","Результаты опроса • %n голоса","Результаты опроса • %n голосов","Результаты опроса • %n голосов"],
    "Your vote is anonymous" : "Ваш голос анонимен",
    "You voted for this option" : "Вы проголосовали за этот вариант",
    "End poll" : "Завершить опрос",
    "Change your vote" : "Изменить ваш голос",
    "Withdraw vote" : "Отозвать голос",
    "Results" : "Результаты",
    "Voted participants" : "Проголосовавшие участники",
    "Send a message to \"{roomName}\"" : "Отправить сообщение в «{roomName}»",
    "Hide list of participants" : "Скрыть список участников",
    "Show list of participants" : "Показать список участников",
    "Assistance requested in {roomName}" : "Запрошена помощь в {roomName}",
    "The message was sent to \"{roomName}\"" : "Сообщение было отправлено в «{roomName}»",
    "Dismiss request for assistance" : "Отклонить запрос о помощи",
    "Send message to room" : "Отправить сообщение в комнату",
    "Back to main room" : "Вернуться в главную комнату",
    "Back to your room" : "Вернуться в свою комнату",
    "Message all rooms" : "Сообщение всем комнатам",
    "Start session" : "Начать сессию",
    "Start a call before you start a breakout room session" : "Начните вызов, прежде чем запустить сессию в комнатах обсуждения",
    "Stop session" : "Остановить сеанс",
    "The message was sent to all breakout rooms" : "Сообщение было отправлено во все комнаты обсуждения",
    "Send a message to all breakout rooms" : "Отправить сообщение во все комнаты обсуждения",
    "Breakout rooms are not started" : "Комнаты обсуждения не запущены",
    "Calls without High-performance backend can cause connectivity issues and high load on devices. {linkstart}Learn more{linkend}" : "Вызовы без Высокопроизводительного сервера могут вызвать проблемы со связью и высокую нагрузку на устройства. {linkstart}Узнать больше{linkend}",
    "Talk setup incomplete" : "Конфигурация Talk не завершена",
    "Disable lobby" : "Отключить лобби",
    "Settings for participant \"{user}\"" : "Параметры участника «{user}»",
    "Participant \"{user}\"" : "Участник «{user}»",
    "moderator" : "модератор",
    "bot" : "бот",
    "guest" : "гость",
    "Ringing …" : "Вызываем ...",
    "Call rejected" : "Вызов отклонен",
    "{time} talking …" : "{time} говорит …",
    "{time} talking time" : "{time} время разговора",
    "Raised their hand" : "Поднял руку",
    "Joined with video" : "Передача видео включена",
    "Joined via phone" : "Телефонное соединение",
    "Joined with audio" : "Передача звука включена",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "Описание должно быть не длиннее {maxLength} символов. Длина введённого текста: {charactersCount} cимволов.",
    "Remove group and members" : "Исключить группу и её участников",
    "Remove team and members" : "Исключить команду и её участников",
    "Remove participant" : "Исключить участника",
    "Do you really want to remove group \"{displayName}\" and its members from this conversation?" : "Вы действительно хотите исключить группу «{displayName}» и её участников из этого обсуждения?",
    "Do you really want to remove team \"{displayName}\" and its members from this conversation?" : "Вы действительно хотите исключить команду «{displayName}» и её участников из этого обсуждения?",
    "Do you really want to remove {displayName} from this conversation?" : "Вы действительно хотите исключить {displayName} из этого обсуждения?",
    "Notification was sent to {displayName}" : "Уведомление было отправлено для {displayName}",
    "Could not send notification to {displayName}" : "Не удалось отправить уведомление для {displayName}",
    "Permissions granted to {displayName}" : "Разрешения предоставлены {displayName}",
    "Could not modify permissions for {displayName}" : "Не удалось изменить разрешения для {displayName}",
    "Permissions removed for {displayName}" : "Разрешения удалены для {displayName}",
    "Permissions set to default for {displayName}" : "Разрешения установлены по умолчанию для {displayName}",
    "Phone number could not be hung up" : "Номер телефона не может быть повешен",
    "Phone number could not be put on hold" : "Номер телефона не может быть поставлен на удержание",
    "Phone number could not be muted" : "Звук для номера телефона не может быть отключен",
    "Phone number could not be unmuted" : "Звук для номера телефона не может быть включен",
    "DTMF message could not be sent" : "DTMF сообщение не может быть отправлено",
    "Phone number copied to clipboard" : "Номер телефона скопирован в буфер обмена",
    "Phone number could not be copied" : "Номер телефона не может быть скопирован",
    "in the lobby" : "В лобби",
    "Dial out phone" : "Набрать номер",
    "Hang up phone" : "Повесить номер",
    "Move back to lobby" : "Отправить в лобби",
    "Move to conversation" : "Добавить в обсуждение",
    "Dial-in PIN" : "PIN для звонка",
    "Demote from moderator" : "Исключить из модераторов",
    "Promote to moderator" : "Назначить модератором",
    "Resend invitation" : "Повторно отправить приглашение",
    "Send call notification" : "Отправить уведомление о вызове",
    "Dial out phone number" : "Набрать номер телефона",
    "Resume call for phone number" : "Продолжить вызов для номера телефона",
    "Put phone number on hold" : "Поставить номер телефона на удержание",
    "Unmute phone number" : "Включить звук для номера телефона",
    "Mute phone number" : "Отключить звук для номера телефона",
    "Copy phone number" : "Копировать номер телефона",
    "Reset custom permissions" : "Сброс пользовательских разрешений",
    "Grant all permissions" : "Предоставить все разрешения",
    "Remove all permissions" : "Удалить все разрешения",
    "Also ban from this conversation" : "Также забанить в этом обсуждении",
    "Internal note (reason to ban)" : "Внутреняя заметка (причина бана)",
    "Remove" : "Исключить",
    "Permissions modified for {displayName}" : "Разрешения изменены для {displayName}",
    "Add users, groups or teams" : "Добавить пользователей, группы или команды",
    "Add users or groups" : "Добавить пользователей или группы",
    "Add users or teams" : "Добавить пользователей или команды",
    "Add users" : "Добавить пользователей",
    "Add groups or teams" : "Добавить группы или команды",
    "Add groups" : "Добавить группы",
    "Add teams" : "Добавить команды",
    "Add other sources" : "Добавить другие источники",
    "Add emails" : "Добавить по адресам эл. почты",
    "Integrations" : "Интеграции",
    "Add federated users" : "Добавить федеративных пользователей",
    "Searching …" : "Поиск…",
    "Search for more users" : "Искать других пользователей",
    "You can search or add participants via name, email, or Federated Cloud ID" : "Вы можете искать или добавлять участников по имени, адресу электронной почты или идентификатору Federated Cloud.",
    "Search or add participants" : "Искать или добавить участников",
    "Invitation was sent to {actorId}" : "Приглашение отправлено {actorId}",
    "An error occurred while adding the participants" : "Произошла ошибка при добавлении участников",
    "A new group conversation with selected participant will be created" : "Будет создано новое групповое обсуждение с выбранным участником",
    "Participants" : "Участники",
    "Pinned by a deleted user" : "Закреплено удаленным пользователем",
    "Participants ({count})" : "Участники ({count})",
    "Open chat" : "Открыть чат",
    "You have new unread messages in the chat." : "В обсуждении имеются непрочитанные сообщения.",
    "You have been mentioned in the chat." : "Вы были упомянуты в обсуждении.",
    "Search messages" : "Искать сообщения",
    "Chat" : "Чат",
    "Details" : "Дополнительно",
    "Shared items" : "Общие элементы",
    "Search in {name}" : "Поиск в {name}",
    "Threads in {name}" : "Темы в {name}",
    "{actor} in {conversation}" : "{actor} в {conversation}",
    "Search messages …" : "Искать сообщения …",
    "Search options" : "Параметры поиска",
    "From User" : "От пользователя",
    "Since" : "С",
    "Until" : "До",
    "No results found" : "Результаты отсутствуют",
    "Load more results" : "Показать больше результатов",
    "Recent threads" : "Недавние темы",
    "Projects" : "Проекты",
    "No shared items" : "Нет общих элементов",
    "Thread notifications" : "Уведомления для темы",
    "Thread actions" : "Действия с темой",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Ссылка на обсуждение",
    "No open conversations found" : "Не найдено ни одного открытого обсуждения",
    "Either there are no open conversations or you joined all of them." : "Открытых обсуждений нет, или вы присоединились ко всем возможным.",
    "Check spelling or use complete words." : "Проверьте правописание или используйте полные слова",
    "Search conversations or users" : "Искать обсуждения или пользователей",
    "Select conversation" : "Выберите обсуждение",
    "Number length is not valid" : "Длина номера некорректна",
    "Region code is not valid" : "Код региона некорректен",
    "Number length is too short" : "Длина номера слишком короткая",
    "Number length is too long" : "Длина номера слишком длинная",
    "Number is not valid" : "Номер указан некорректно",
    "Phone numbers" : "Номера телефонов",
    "Display name: {name}" : "Отображаемое имя: {name}",
    "Edit display name" : "Изменить отображаемое имя",
    "Display name (required)" : "Отображаемое имя (обязательно)",
    "Save name" : "Сохранить имя",
    "I picked message bubbles" : "Я выбираю пузыри сообщений",
    "I picked the list style" : "Я выбираю в стиле списка",
    "Error while setting personal setting" : "Ошибка при сохранении персональных параметров",
    "Error while saving sounds setting" : "Не удалось сохранить параметры звука",
    "Compact conversations list" : "Компактный список обсуждений",
    "Chat appearance" : "Внешний вид чата",
    "Messages list" : "Список сообщений",
    "Message bubbles" : "Сообщения в пузырях",
    "Play sounds when participants join or leave a call" : "Воспроизводить звуки, когда участники присоединяются к вызову или покидают его",
    "Currently not available on iPhone and iPad due to technical restrictions by the manufacturer" : "В настоящее время недоступно на iPhone и iPad из-за технических ограничений производителя.",
    "Notification settings" : "Настройки уведомлений",
    "Sounds for chat and call notifications" : "Звуки уведомлений о новых сообщениях или вызове",
    "Invalid language ({languageId})" : "Недопустимый язык ({languageId})",
    "Default language" : "Язык по умолчанию",
    "Default language ({languageName})" : "Язык по умолчанию ({languageName})",
    "Error when trying to load the available live translation languages" : "Ошибка при попытке загрузить доступные языки для онлайн-перевода",
    "Error when trying to set live translation language" : "Ошибка при попытке установить язык для онлайн-перевода",
    "Set language used to show the transcriptions" : "Установить язык для отображения транскрипции",
    "Select location for attachments" : "Выберите путь для сохранения вложений",
    "Error while setting attachment folder" : "Не удалось задать папку для вложений",
    "Error while setting read status privacy" : "Не удалось сохранить параметр состояния прочтения",
    "Error while setting typing status privacy" : "Ошибка при настройке конфиденциальности статуса ввода",
    "Error while setting default media state" : "Ошибка при сохранении параметров медиа по умолчанию",
    "Turn camera and microphone off by default" : "Отключить камеру и микрофон по умолчанию",
    "Blur camera background by default" : "Размытие фона камеры по умолчанию",
    "Skip device preview before joining a call" : "Пропустить просмотр устройств перед присоединением к вызову",
    "Appearance & Sounds" : "Внешний вид и звуковые уведомления",
    "Privacy" : "Конфиденциальность",
    "Send read receipts" : "Делиться уведомлениями о прочтении",
    "When off, all read statuses will be hidden" : "Если выключено, все уведомления о прочтении будут скрыты",
    "Share typing status" : "Делиться статусом набора текста",
    "When off, all typing indicators will be hidden" : "Если выключено, все статусы набора текста будут скрыты",
    "Attachments folder" : "Папка для вложений",
    "Toggle full screen" : "Переключиться на полный экран",
    "Return to Home screen" : "Вернуться на начальный экран",
    "Search" : "Поиск",
    "Shortcuts while in a chat" : "Комбинации клавиш в чате",
    "Focus the chat input" : "Переключиться в окно ввода текста",
    "Unfocus the chat input to use shortcuts" : "Переключиться из поля ввода текста для использования комбинаций клавиш",
    "Edit your last message" : "Изменить Ваше последнее сообщение",
    "Shortcuts while in a call" : "Комбинации клавиш во время вызова",
    "Camera on and off" : "Включение и выключение камеры",
    "Microphone on and off" : "Включить или отключить микрофон",
    "Raise or lower hand" : "Поднять или опустить руку",
    "Push to talk or push to mute" : "Кнопка для включения (PTT) или отключения (PTM) передачи голоса ",
    "Zoom-in / zoom-out a screen share" : "Увеличить / уменьшить масштаб трансляции экрана",
    "Mouse wheel" : "Колесо мыши",
    "Start call silently" : "Начать тихий вызов",
    "Start call" : "Начать вызов",
    "End call" : "Завершить вызов",
    "The server was updated, you cannot start or join a call." : "Сервер был обновлен, вы не можете начать или присоединиться к вызову.",
    "This call has just ended" : "Этот вызов только что завершён",
    "You will be able to join the call only after a moderator starts it." : "Вы сможете присоединиться к вызову только после того, как его начнет модератор.",
    "End call for everyone" : "Завершить вызов для всех",
    "Starting the recording" : "Начало записи",
    "Recording" : "Запись",
    "The call has been running for one hour." : "Вызов длится уже более часа",
    "Cancel recording start" : "Отменить начало записи",
    "Stop recording" : "Остановить запись",
    "Send a reaction" : "Отправить реакцию",
    "React with {reaction}" : "Отреагировать с {reaction}",
    "All tasks done!" : "Все задачи выполнены!",
    "_{done} of %n task_::_{done} of %n tasks_" : ["{done} из %n задач","{done} из %n задач","{done} из %n задач","{done} из %n задач"],
    "Add participants to this call" : "Добавить участников в этот вызов",
    "_%n participant in call_::_%n participants in call_" : ["%n участник в вызове","%n участника в вызове","%n участников в вызове","%n участников в вызове"],
    "Scheduled messages" : "Запланированные сообщения",
    "You are not allowed to enable screensharing" : "Вам не разрешено транслировать экран",
    "No screensharing" : "Трансляция экрана недоступна",
    "Screensharing options" : "Параметры трансляции экрана",
    "Enable screensharing" : "Включить трансляцию экрана",
    "Bad sent video and screen quality." : "Плохое качество видео и изображения.",
    "Bad sent screen quality." : "Плохое качество изображения.",
    "Bad sent video quality." : "Плохое качество видео.",
    "Bad sent audio, video and screen quality." : "Плохое качество звука, видео и изображения.",
    "Bad sent audio and screen quality." : "Плохое качество звука и изображения.",
    "Bad sent audio and video quality." : "Плохое качество звука и видео.",
    "Bad sent audio quality." : "Плохое качество звука.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "Ваше интернет соединение или компьютер перегружены, и другие участники не могут видеть ваш экран. Чтобы исправить, попробуйте отключить размытие фона или видео во время трансляции экрана.",
    "Disable background blur" : "Отключить размытый фон",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Ваше интернет соединение или компьютер перегружены, и другие участники не могут видеть ваш экран. Чтобы исправить, попробуйте отключить видео во время трансляции экрана.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Ваше интернет-подключение или компьютер сильно загружены и другие пользователи могут не видеть ваш экран.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "Ваше интернет-подключение или компьютер сильно загружены и другие пользователи могут вас не видеть.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "Ваше интернет соединение или компьютер перегружены, и другие участники не могут видеть ваш экран. Чтобы исправить, попробуйте отключить размытие фона или видео во время трансляции экрана.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Ваше интернет-подключение или компьютер сильно загружены и другие пользователи могут вас не понимать или не видеть. Для улучшения ситуации попробуйте отключить видео во время трансляции экрана.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "Ваше интернет соединение или компьютер перегружены, и другие участники не могут видеть ваш экран. Чтобы исправить, попробуйте отключить трансляцию экрана.",
    "Disable screenshare" : "Отключить трансляцию экрана",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "Ваше интернет соединение или компьютер перегружены, и другие участники не могут видеть ваш экран. Чтобы исправить, попробуйте отключить размытие фона или видео.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Ваше интернет-подключение или компьютер сильно загружены и другие пользователи могут вас не понимать или не видеть. Для улучшения ситуации попробуйте отключить видео.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Ваше интернет-подключение или компьютер сильно загружены и другие пользователи могут вас не понимать.",
    "Screen sharing is not supported by your browser." : "Ваш браузер не подерживает трансляцию экрана.",
    "Screen sharing requires the page to be loaded through HTTPS." : "Для трансляции экрана требуется загрузка этой страницы с использованием протокола HTTPS.",
    "Screensharing requires the page to be loaded through HTTPS." : "Для трансляции экрана требуется загрузка этой страницы с использованием протокола HTTPS.",
    "An error occurred while starting screensharing." : "Не удалось начать трансляцию экрана.",
    "Select virtual background" : "Выбрать виртуальный фон",
    "Show your screen" : "Показать ваш экран",
    "Stop screensharing" : "Прекратить трансляцию экрана",
    "Mute others" : "Отключить микрофоны других пользователей",
    "Start recording" : "Начать запись",
    "Set up breakout rooms" : "Настроить комнаты обсуждения",
    "Download attendance list" : "Скачать список участников",
    "Open Calendar" : "Окрыть календарь",
    "Remove participant {name}" : "Исключить участника {name}",
    "Would you like to delete this conversation?" : "Вы хотите удалить это обсуждение?",
    "_This conversation will be automatically deleted for everyone after %n day of inactivity._::_This conversation will be automatically deleted for everyone after %n days of inactivity._" : ["Обсуждение будет автоматически удалено для всех после %n дня отсутствия активности.","Обсуждение будет автоматически удалено для всех после %n дней отсутствия активности.","Обсуждение будет автоматически удалено для всех после %n дней отсутствия активности.","Обсуждение будет автоматически удалено для всех после %n дней отсутствия активности."],
    "Are you sure you want to delete this conversation?" : "Вы уверены, что хотите удалить это обсуждение?",
    "Delete now" : "Удалить сейчас",
    "Keep" : "Сохранить",
    "Open dialpad" : "Открыть панель набора",
    "Select a region" : "Выберите регион",
    "Local time: {time}" : "Местное время: {time}",
    "Scheduled {datetime}" : "Запланировано {datetime} ",
    "Scheduled for {datetime}" : "Запланировано на {datetime}",
    "Search …" : "Поиск …",
    "Message without mention" : "Сообщение без упоминания",
    "Mention myself" : "Упоминание себя",
    "Mention everyone" : "Упомянуть всех",
    "Select a conversation" : "Выберите обсуждение",
    "Select a mode" : "Выберите режим",
    "You do not have permissions to access this conversation." : "У вас нет прав доступа к этому обсуждению.",
    "Join a different conversation or start a new one." : "Присоединитесь к другому обсуждению или начните новое.",
    "The conversation does not exist" : "Обсуждения не существует",
    "Join a conversation or start a new one!" : "Присоединитесь к обсуждению или начните новое!",
    "Duplicate session" : "Повторяющийся сеанс",
    "This conversation was opened in another tab. The current server version does not support opening a conversation in multiple tabs." : "Обсуждение было открыто в другой вкладке. Текущая версия сервера не поддерживает открытие одного обсуждения в нескольких вкладках.",
    "Creating and joining a conversation with \"{userid}\"" : "Создание и присоединение к обсуждению с пользователем \"{userid}\"",
    "Join a conversation or start a new one" : "Присоединитесь к обсуждению или начните новое",
    "Error while joining the conversation" : "Ошибка при присоединении к обсуждению",
    "Another user" : "Другой пользователь",
    "Hey! Are you using the list style or message bubbles?" : "Привет! Ты используешь чат в Конференциях в стиле списка или пузырей?",
    "Nextcloud URL" : "Адрес сервера Nextcloud",
    "Nextcloud user" : "Имя пользователя Nextcloud",
    "User password" : "Пароль пользователя",
    "Talk conversation" : "Название обсуждения",
    "Skip TLS verification" : "Не использовать проверку подлинности TLS",
    "Matrix server URL" : "Адрес сервера Matrix",
    "User" : "Пользователь",
    "Matrix channel" : "Канал Matrix",
    "Mattermost server URL" : "Адрес сервера Mattermost",
    "Mattermost user" : "Пользователь Mattermost",
    "Team name" : "Название команды",
    "Channel name" : "Название канала",
    "Rocket.Chat server URL" : "URL сервера Rocket.Chat",
    "User name or email address" : "Имя пользователя или адрес эл. почты",
    "Rocket.Chat channel" : "Канал Rocket.Chat",
    "Zulip server URL" : "Адрес сервера Zulip",
    "Bot user name" : "Имя пользователя-бота",
    "Bot API key" : "Ключ API бота",
    "Zulip channel" : "Канал Zulip",
    "API token" : "API токен",
    "Slack channel" : "Канал Slack",
    "Server ID or name" : "ID или имя сервера",
    "Channel ID (prefixed with \"ID:\") or name" : "ID канала (с префиксом \"ID:\") или имя",
    "Channel" : "Канал",
    "Login" : "Логин",
    "Chat ID" : "ID чата",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "Адрес сервера IRC (к примеру: chat.freenode.net:6667)",
    "Nickname" : "Псевдоним",
    "Connection password" : "Пароль для подключения",
    "IRC channel" : "Канал IRC",
    "Channel password" : "Пароль для канала",
    "NickServ nickname" : "Псевдоним NickServ",
    "NickServ password" : "Пароль для NickServ",
    "Use TLS" : "Использовать TLS",
    "Use SASL" : "Использовать SASL",
    "Tenant ID" : "ID участника",
    "Client ID" : "ID клиента",
    "Team ID" : "ID команды",
    "Thread ID" : "ID ветки обсуждения",
    "XMPP/Jabber server URL" : "Адрес сервера XMPP или Jabber",
    "MUC server URL" : "Адрес сервера MUC",
    "Jabber ID" : "Jabber ID",
    "Pinned messages" : "Закрепленные сообщения",
    "Media" : "Медиа",
    "Polls" : "Опросы",
    "Deck cards" : "Карточки",
    "Voice messages" : "Голосовые сообщения",
    "Locations" : "Места",
    "Call recordings" : "Записи вызовов",
    "Audio" : "Звук",
    "Show all pinned messages" : "Показать все закрепленные сообщения",
    "Show all media" : "Показать все медиа",
    "Show all files" : "Показать все файлы",
    "Show all polls" : "Показать все опросы",
    "Show all deck cards" : "Показать все карточки",
    "Show all voice messages" : "Показать все голосовые сообщения",
    "Show all locations" : "Показать все местоположения",
    "Show all call recordings" : "Показать все записи вызовов",
    "Show all audio" : "Показать все аудио",
    "Show all other" : "Показать все остальное",
    "Follow conversation settings" : "Следовать настройкам обсуждения",
    "Group" : "Группа",
    "Team" : "Команда",
    "You reconnected to the call" : "Вы переподключились к вызову",
    "{actor} reconnected to the call" : "{actor} переподключился(лась) к вызову",
    "You added {user0} and {user1}" : "Вы добавили {user0} и {user1}",
    "_You added {user0}, {user1} and %n more participant_::_You added {user0}, {user1} and %n more participants_" : ["Вы добавили {user0}, {user1} и ещё %n участника","Вы добавили {user0}, {user1} и ещё %n участников","Вы добавили {user0}, {user1} и ещё %n участников","Вы добавили {user0}, {user1} и ещё %n участников"],
    "An administrator added you and {user0}" : "Администратор добавил Вас и {user0} ",
    "{actor} added you and {user0}" : "{actor} добавил(а) Вас и {user0}",
    "_An administrator added you, {user0} and %n more participant_::_An administrator added you, {user0} and %n more participants_" : ["Администратор добавил Вас, {user0} и ещё %n участника","Администратор добавил Вас, {user0} и ещё %n участников","Администратор добавил Вас, {user0} и ещё %n участников","Администратор добавил Вас, {user0} и ещё %n участников"],
    "_{actor} added you, {user0} and %n more participant_::_{actor} added you, {user0} and %n more participants_" : ["{actor} добавил(а) Вас, {user0} и ещё %n участника","{actor} добавил(а) Вас, {user0} и ещё %n участников","{actor} добавил(а) Вас, {user0} и ещё %n участников","{actor} добавил(а) Вас, {user0} и ещё %n участников"],
    "An administrator added {user0} and {user1}" : "Администратор добавил {user0} и {user1} ",
    "{actor} added {user0} and {user1}" : "{actor} добавил(а) {user0} и {user1}",
    "_An administrator added {user0}, {user1} and %n more participant_::_An administrator added {user0}, {user1} and %n more participants_" : ["Администратор добавил {user0}, {user1} и ещё %n участника","Администратор добавил {user0}, {user1} и ещё %n участников","Администратор добавил {user0}, {user1} и ещё %n участников","Администратор добавил {user0}, {user1} и ещё %n участников"],
    "_{actor} added {user0}, {user1} and %n more participant_::_{actor} added {user0}, {user1} and %n more participants_" : ["{actor} добавил(а) {user0}, {user1} и ещё %n участника","{actor} добавил(а) {user0}, {user1} и ещё %n участников","{actor} добавил(а) {user0}, {user1} и ещё %n участников","{actor} добавил(а) {user0}, {user1} и ещё %n участников"],
    "You removed {user0} and {user1}" : "Вы исключили {user0} и {user1}",
    "_You removed {user0}, {user1} and %n more participant_::_You removed {user0}, {user1} and %n more participants_" : ["Вы исключили {user0}, {user1} и ещё %n участника","Вы исключили {user0}, {user1} и ещё %n участников","Вы исключили {user0}, {user1} и ещё %n участников","Вы исключили {user0}, {user1} и ещё %n участников"],
    "An administrator removed you and {user0}" : "Администратор исключил Вас и {user0} ",
    "{actor} removed you and {user0}" : "{actor} исключил(а) Вас и {user0}",
    "_An administrator removed you, {user0} and %n more participant_::_An administrator removed you, {user0} and %n more participants_" : ["Администратор исключил Вас, {user0} и ещё %n участника","Администратор исключил Вас, {user0} и ещё %n участников","Администратор исключил Вас, {user0} и ещё %n участников","Администратор исключил Вас, {user0} и ещё %n участников"],
    "_{actor} removed you, {user0} and %n more participant_::_{actor} removed you, {user0} and %n more participants_" : ["{actor} исключил(а) Вас, {user0} и ещё %n участника","{actor} исключил(а) Вас, {user0} и ещё %n участников","{actor} исключил(а) Вас, {user0} и ещё %n участников","{actor} исключил(а) Вас, {user0} и ещё %n участников"],
    "An administrator removed {user0} and {user1}" : "Администратор исключил {user0} и {user1} ",
    "{actor} removed {user0} and {user1}" : "{actor} исключил(а) {user0} и {user1}",
    "_An administrator removed {user0}, {user1} and %n more participant_::_An administrator removed {user0}, {user1} and %n more participants_" : ["Администратор исключил {user0}, {user1} и ещё %n участника","Администратор исключил {user0}, {user1} и ещё %n участников","Администратор исключил {user0}, {user1} и ещё %n участников","Администратор исключил {user0}, {user1} и ещё %n участников"],
    "_{actor} removed {user0}, {user1} and %n more participant_::_{actor} removed {user0}, {user1} and %n more participants_" : ["{actor} исключил(а) {user0}, {user1} и ещё %n участника","{actor} исключил(а) {user0}, {user1} и ещё %n участников","{actor} исключил(а) {user0}, {user1} и ещё %n участников","{actor} исключил(а) {user0}, {user1} и ещё %n участников"],
    "You and {user0} joined the call" : "Вы и {user0} присоединились к вызову",
    "_You, {user0} and %n more participant joined the call_::_You, {user0} and %n more participants joined the call_" : ["Вы, {user0} и ещё %n участник присоединились к вызову","Вы, {user0} и ещё %n участника присоединились к вызову","Вы, {user0} и ещё %n участников присоединились к вызову","Вы, {user0} и ещё %n участников присоединились к вызову"],
    "{user0} and {user1} joined the call" : "{user0} и {user1} присоединились к вызову",
    "_{user0}, {user1} and %n more participant joined the call_::_{user0}, {user1} and %n more participants joined the call_" : ["{user0}, {user1} и ещё %n участник присоединились к вызову","{user0}, {user1} и ещё %n участника присоединились к вызову","{user0}, {user1} и ещё %n участников присоединились к вызову","{user0}, {user1} и ещё %n участников присоединились к вызову"],
    "You and {user0} left the call" : "Вы и {user0} покинули вызов",
    "_You, {user0} and %n more participant left the call_::_You, {user0} and %n more participants left the call_" : ["Вы, {user0} и ещё %n участник покинули вызов","Вы, {user0} и ещё %n участника покинули вызов","Вы, {user0} и ещё %n участников покинули вызов","Вы, {user0} и ещё %n участников покинули вызов"],
    "{user0} and {user1} left the call" : "{user0} и {user1} покинули вызов",
    "_{user0}, {user1} and %n more participant left the call_::_{user0}, {user1} and %n more participants left the call_" : ["{user0}, {user1} и ещё %n участник покинули вызов","{user0}, {user1} и ещё %n участника покинули вызов","{user0}, {user1} и ещё %n участников покинули вызов","{user0}, {user1} и ещё %n участников покинули вызов"],
    "You promoted {user0} and {user1} to moderators" : "Вы назначили {user0} и {user1} модераторами",
    "_You promoted {user0}, {user1} and %n more participant to moderators_::_You promoted {user0}, {user1} and %n more participants to moderators_" : ["Вы назначили {user0}, {user1} и ещё %n участника модераторами","Вы назначили {user0}, {user1} и ещё %n участников модераторами","Вы назначили {user0}, {user1} и ещё %n участников модераторами","Вы назначили {user0}, {user1} и ещё %n участников модераторами"],
    "An administrator promoted you and {user0} to moderators" : "Администратор назначил Вас и {user0} модераторами",
    "{actor} promoted you and {user0} to moderators" : "{actor} назначил(а) Вас и {user0} модераторами",
    "_An administrator promoted you, {user0} and %n more participant to moderators_::_An administrator promoted you, {user0} and %n more participants to moderators_" : ["Администратор назначил Вас, {user0} и ещё %n участника модераторами","Администратор назначил Вас, {user0} и ещё %n участников модераторами","Администратор назначил Вас, {user0} и ещё %n участников модераторами","Администратор назначил Вас, {user0} и ещё %n участников модераторами"],
    "_{actor} promoted you, {user0} and %n more participant to moderators_::_{actor} promoted you, {user0} and %n more participants to moderators_" : ["{actor} назначил(а) Вас, {user0} и ещё %n участника модераторами","{actor} назначил(а) Вас, {user0} и ещё %n участников модераторами","{actor} назначил(а) Вас, {user0} и ещё %n участников модераторами","{actor} назначил(а) Вас, {user0} и ещё %n участников модераторами"],
    "An administrator promoted {user0} and {user1} to moderators" : "Администратор назначил {user0} и {user1} модераторами",
    "{actor} promoted {user0} and {user1} to moderators" : "{actor} назначил(а) {user0} и {user1} модераторами",
    "_An administrator promoted {user0}, {user1} and %n more participant to moderators_::_An administrator promoted {user0}, {user1} and %n more participants to moderators_" : ["Администратор назначил {user0} , {user1} и ещё %n участника модераторами","Администратор назначил {user0} , {user1} и ещё %n участников модераторами","Администратор назначил {user0} , {user1} и ещё %n участников модераторами","Администратор назначил {user0} , {user1} и ещё %n участников модераторами"],
    "_{actor} promoted {user0}, {user1} and %n more participant to moderators_::_{actor} promoted {user0}, {user1} and %n more participants to moderators_" : ["{actor} назначил(а) {user0}, {user1} и ещё %n участника модераторами","{actor} назначил(а) {user0}, {user1} и ещё %n участников модераторами","{actor} назначил(а) {user0}, {user1} и ещё %n участников модераторами","{actor} назначил(а) {user0}, {user1} и ещё %n участников модераторами"],
    "You demoted {user0} and {user1} from moderators" : "Вы исключили {user0} и {user1} из модераторов",
    "_You demoted {user0}, {user1} and %n more participant from moderators_::_You demoted {user0}, {user1} and %n more participants from moderators_" : ["Вы исключили {user0}, {user1} и ещё %n участника из модераторов","Вы исключили {user0}, {user1} и ещё %n участников из модераторов","Вы исключили {user0}, {user1} и ещё %n участников из модераторов","Вы исключили {user0}, {user1} и ещё %n участников из модераторов"],
    "An administrator demoted you and {user0} from moderators" : "Администратор исключил Вас и {user0} из модераторов",
    "{actor} demoted you and {user0} from moderators" : "{actor} исключил(а) Вас и {user0} из модераторов",
    "_An administrator demoted you, {user0} and %n more participant from moderators_::_An administrator demoted you, {user0} and %n more participants from moderators_" : ["Администратор исключил Вас, {user0} и ещё %n участника из модераторов","Администратор исключил Вас, {user0} и ещё %n участников из модераторов","Администратор исключил Вас, {user0} и ещё %n участников из модераторов","Администратор исключил Вас, {user0} и ещё %n участников из модераторов"],
    "_{actor} demoted you, {user0} and %n more participant from moderators_::_{actor} demoted you, {user0} and %n more participants from moderators_" : ["{actor} исключил(а) Вас, {user0} и ещё %n участника из модераторов","{actor} исключил(а) Вас, {user0} и ещё %n участников из модераторов","{actor} исключил(а) Вас, {user0} и ещё %n участников из модераторов","{actor} исключил(а) Вас, {user0} и ещё %n участников из модераторов"],
    "An administrator demoted {user0} and {user1} from moderators" : "Администратор исключил {user0} и {user1} из модераторов",
    "{actor} demoted {user0} and {user1} from moderators" : "{actor} исключил(а) {user0} и {user1} из модераторов",
    "_An administrator demoted {user0}, {user1} and %n more participant from moderators_::_An administrator demoted {user0}, {user1} and %n more participants from moderators_" : ["Администратор исключил {user0}, {user1} и ещё %n участника из модераторов","Администратор исключил {user0}, {user1} и ещё %n участников из модераторов","Администратор исключил {user0}, {user1} и ещё %n участников из модераторов","Администратор исключил {user0}, {user1} и ещё %n участников из модераторов"],
    "_{actor} demoted {user0}, {user1} and %n more participant from moderators_::_{actor} demoted {user0}, {user1} and %n more participants from moderators_" : ["{actor} исключил(а) {user0}, {user1} и ещё %n участника из модераторов","{actor} исключил(а) {user0}, {user1} и ещё %n участников из модераторов","{actor} исключил(а) {user0}, {user1} и ещё %n участников из модераторов","{actor} исключил(а) {user0}, {user1} и ещё %n участников из модераторов"],
    "You:" : "Вы:",
    "You: {lastMessage}" : "Вы: {lastMessage}",
    "{actor}:" : "{actor}:",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "The server was updated." : "Сервер был обновлен.",
    "(edited by you)" : "(изменено Вами)",
    "(edited by a deleted user)" : "(изменено удаленным пользователем)",
    "(edited by {moderator})" : "(изменено {moderator})",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Вы пытаетесь присоединиться к обсуждению, в котором уже есть активные сессии из другого окна или устройства. В данный момент данная возможность не поддерживается сервером Nextcloud Talk. Что вы хотите сделать?",
    "Leave this page" : "Покинуть страницу",
    "Join here" : "Присоединиться",
    "Deck card has been posted to {conversation}" : "Карточка была отправлена в {conversation}",
    "An error occurred while posting deck card to conversation" : "Произошла ошибка при отправке карточки в обсуждение",
    "Post to a conversation" : "Опубликовать в обсуждении",
    "Post to conversation" : "Опубликовать в обсуждении",
    "The recording failed. Please contact your administrator." : "Не удалось записать звонок. Пожалуйста, свяжитесь с администратором.",
    "Location has been posted to {conversation}" : "Местоположение было отправлено в {conversation}",
    "An error occurred while posting location to conversation" : "Произошла ошибка при отправке местоположения в обсуждение",
    "Share to a conversation" : "Опубликовать в обсуждении",
    "Share to conversation" : "Опубликовать в обсуждении",
    "In conversation" : "В обсуждении",
    "Search in conversation: {conversation}" : "Найти в обсуждении: {conversation}",
    "Your requests are throttled at the moment due to brute force protection" : "В настоящий момент ваши запросы ограничены из-за защиты от брутфорс-атак",
    "Error while clearing conversation history" : "Не удалось удалить историю сообщений обсуждения",
    "Error occurred while allowing guests" : "Произошла ошибка при открытии доступа для гостей",
    "Error occurred while disallowing guests" : "Произошла ошибка при закрытии доступа для гостей",
    "Error occurred when restricting the conversation to moderator" : "Не удалось ограничить доступ к обсуждению только для модераторов",
    "Error occurred when opening the conversation to everyone" : "Не удалось открыть доступ к обсуждению всем пользователям",
    "Conversation password has been saved" : "Пароль для обсуждения сохранён",
    "Conversation password has been removed" : "Пароль обсуждения был удалён",
    "Error occurred while saving conversation password" : "Не удалось сохранить пароль для обсуждения",
    "Call recording is starting." : "Начата запись вызова.",
    "Call recording stopped while starting." : "Запись вызова остановлена ​​при запуске.",
    "Call recording stopped. You will be notified once the recording is available." : "Запись вызова остановлена. Вы будете уведомлены, как только запись будет доступна.",
    "Conversation picture set" : "Изображение обсуждения установлено",
    "Conversation picture deleted" : "Изображение обсуждения удалено",
    "Could not delete the conversation picture" : "Не удалось удалить изображение обсуждения",
    "Could not remove the automatic expiration" : "Не удалось удалить автоматическое истечение срока действия",
    "Could not post message: {errorMessage}" : "Не удалось опубликовать сообщение: {errorMessage}",
    "Participant is banned successfully" : "Участник успешно забанен",
    "Error while banning the participant" : "Ошибка при бане участника",
    "An error occurred while fetching the participants" : "Произошла ошибка при получении списка участников",
    "Could not send invitation to {actorId}" : "Не удалось отправить приглашение {actorId}",
    "Invitations sent" : "Приглашения отправлены",
    "Error occurred when sending invitations" : "Не удалось отправить приглашения",
    "Failed to join the conversation." : "Не удалось присоединиться к обсуждению.",
    "An error occurred while creating breakout rooms" : "Произошла ошибка при создании комнат обсуждения",
    "An error occurred while re-ordering the attendees" : "Произошла ошибка при изменении порядка участников",
    "An error occurred while deleting breakout rooms" : "Произошла ошибка при удалении комнат обсуждения",
    "An error occurred while starting breakout rooms" : "Произошла ошибка при запуске комнат обсуждения",
    "An error occurred while stopping breakout rooms" : "Произошла ошибка при остановке комнат обсуждения",
    "An error occurred while sending a message to the breakout rooms" : "Произошла ошибка при отправке сообщения в комнаты обсуждения",
    "An error occurred while requesting assistance" : "Произошла ошибка при запросе помощи",
    "An error occurred while resetting the request for assistance" : "Произошла ошибка при сбросе запроса на помощь",
    "An error occurred while joining breakout room" : "Произошла ошибка при присоединении к комнате обсуждения",
    "Failed to rename the thread" : "Не удалось переименовать тему",
    "Error fetching upcoming events" : "Ошибка при загрузке предстоящих встреч",
    "Error fetching upcoming reminders" : "Ошибка при загрузке предстоящих напоминаний",
    "An error occurred while accepting an invitation" : "Произошла ошибка при принятии приглашения",
    "An error occurred while rejecting an invitation" : "Произошла ошибка при отклонении приглашения",
    "{guest} (guest)" : "{guest} (гость)",
    "Poll draft has been saved" : "Черновик опроса сохранён",
    "An error occurred while saving the draft" : "Произошла ошибка при сохранении черновика",
    "An error occurred while submitting your vote" : "При отправке вашего голоса произошла ошибка",
    "An error occurred while ending the poll" : "Произошла ошибка при завершении опроса",
    "An error occurred while deleting the poll draft" : "Произошла ошибка при удалении черновика опроса",
    "Poll \"{name}\" was created by {user}. Click to vote" : "Опрос «{name}» создан {user}. Нажмите, чтобы проголосовать",
    "Failed to add reaction" : "Не удалось добавить раакцию",
    "Failed to remove reaction" : "Не удалось удалить реакцию",
    "The server is in maintenance mode." : "Сервер в режиме обслуживания.",
    "Federated server was updated." : "Федеративный сервер был обновлен.",
    "Error while uploading file \"{fileName}\"" : "Не удалось передать на сервер файл «{fileName}»",
    "Not enough free space to upload file \"{fileName}\"" : "Недостаточно свободного места для передачи на сервер файла «{fileName}» ",
    "You are not allowed to share files" : "Вам не разрешено публиковать файлы",
    "Error while sharing file" : "Ошибка сохранения файла",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Приложение Talk для Nextcloud не полностью поддерживает браузер, который вы используете. Рекомендованные браузеры: Mozilla Firefox, Microsoft Edge, Google Chrome, Opera и Apple Safari.",
    "_In %n hour_::_In %n hours_" : ["Через %n час","Через %n часа","Через %n часов","Через %n часов"],
    "_%n minute _::_%n minutes_" : ["%n минуту","%n минуты","%n минут","%n минут"],
    "In {hours} and {minutes}" : "Через {hours} и {minutes}",
    "_In %n minute_::_In %n minutes_" : ["Через %n минуту","Через %n минуты","Через %n минут","Через %n минут"],
    "Later today – {timeLocale}" : "Позднее сегодня – {timeLocale}",
    "Set time for later today" : "Установить время позднее сегодня",
    "Tomorrow – {timeLocale}" : "Завтра – {timeLocale}",
    "Set time for tomorrow" : "Установить время на завтра",
    "This weekend – {timeLocale}" : "Эти выходные – {timeLocale}",
    "Set time for this weekend" : "Установить время на эти выходные",
    "Next week – {timeLocale}" : "Следующая неделя – {timeLocale}",
    "Set time for next week" : "Установить время на следующую неделю",
    "Message link copied to clipboard" : "Ссылка на сообщение скопирована в буфер обмена",
    "Conversation link copied to clipboard" : "Ссылка на обсуждение скопирована в буфер обмена",
    "The link could not be copied" : "Не удалось скопировать ссылку",
    "Error while parsing a PROPFIND error" : "Ошибка при анализе ошибки PROPFIND",
    "Sending signaling message has failed" : "Не удалось отправить сигнальное сообщение.",
    "Lost connection to signaling server. Trying to reconnect." : "Потеряно соединение с сигнальным сервером. Попытка переподключения.",
    "Lost connection to signaling server." : "Потеряно соединение с сигнальным сервером.",
    "Connecting is taking longer than expected …" : "Подключение занимает больше времени чем ожидалось …",
    "Failed to connect. Retrying …" : "Не удалось подключиться. Повторная попытка …",
    "Failed to connect. The signaling server may be set up incorrectly" : "Не удалось подключиться. Сигнальный сервер может быть неверно настроен",
    "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration." : "Настроенный сигнальный сервер необходимо обновить, чтобы он был совместим с этой версией Talk. Пожалуйста, свяжитесь с вашей технической поддержкой.",
    "Please restart the app." : "Пожалуйста, перезапустите приложение.",
    "Please reload the page." : "Обновите страницу.",
    "Please try to restart the app." : "Пожалуйста, попробуйте перезапустить приложение.",
    "Please try to reload the page." : "Пожалуйста, попробуйте перезагрузить страницу.",
    "Do not disturb" : "Не беспокоить",
    "Away" : "Отсутствует",
    "Microphone {number}" : "Микрофон {number}",
    "Camera {number}" : "Камера {number}",
    "Speaker {number}" : "Выступающий {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Похоже, что вы разговариваете с выключенным звуком, пожалуйста, включите звук, чтобы другие смогли услышать вас",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Не удалось установить соединение хотя бы с одним участником. Сервер TURN может быть необходим для вашего сценария. Пожалуйста, попросите вашего администратора настроить его, следуя {linkstart} этой документации {linkend}.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Это занимает больше времени, чем ожидалось. Проверьте, установлены ли медиаразрешения браузера? Если да, пожалуйста, перезапустите браузер, так как аудио и видео не работают",
    "Access to microphone & camera is only possible with HTTPS" : "Доступ к микрофону и камере возможен только по HTTPS",
    "Please move your setup to HTTPS" : "Пожалуйста, используйте HTTPS",
    "Access to microphone & camera was denied" : "Доступ к микрофону и камере был запрещён",
    "WebRTC is not supported in your browser" : "Технология WebRTC не поддерживается вашим браузером",
    "Please use a different browser like Firefox or Chrome" : "Воспользуйтесь другим браузером, например Firefox или Chrome",
    "Error while accessing microphone & camera" : "Ошибка при доступе к микрофону и камере",
    "%s Talk on your mobile devices" : "%s Talk для мобильных устройств",
    "Join conversations at any time, anywhere, on any device." : "Присоединяйтесь к обсуждениям в любое время, в любом месте, с любого устройства.",
    "Android app" : "Android приложение",
    "iOS app" : "iOS приложение",
    "__language_name__" : "Русский",
    "Webhook Demo" : "Webhook демо",
    "Call summary (%s)" : "Резюме вызова (%s)",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "Бот для резюме вызова публикует обзорное сообщение сразу после вызова с перечислением всех участников и описанием задач",
    "Tasks" : "Задачи",
    "Notes" : "Заметки",
    "Reports" : "Отчёты",
    "Decisions" : "Итоги",
    "Agenda" : "Агенда",
    "Call summary" : "Резюме вызова",
    "Call summary - {title}" : "Резюме вызова - {title}",
    "Talk conversation for event" : "Обсуждение события в Talk",
    "Client Push is installed, this improves the performance of desktop clients." : "«Client Push» установлен, это улучшает производительность настольных ПК-клиентов.",
    "{notify_push} is not installed, this might lead to performance issues when using desktop clients." : "«{notify_push}»  не установлен, это может привести к проблемам с производительностью при использовании настольных ПК-клиентов.",
    "Next meeting" : "Следующая встреча",
    "Schedule a meeting from your calendar. A Talk conversation needs to be set as location to show up here" : "Запланируйте встречу из своего календаря. Обсуждение должно быть установлено как местоположение, чтобы отобразиться здесь",
    "Join conversations from remote Nextcloud servers" : "Присоединитесь к беседам на удалённых серверах Nextcloud",
    "Your default media state has been saved" : "Параметры медиа по умолчанию сохранены",
    "Set reminder for later today" : "Установить напоминание позднее сегодня",
    "Set reminder for tomorrow" : "Установить напоминание на завтра",
    "Set reminder for this weekend" : "Установить напоминание на эти выходные",
    "Set reminder for next week" : "Установить напоминание на следующую неделю",
    "Generate summary" : "Сгенерировать резюме",
    "Open poll • You voted already" : "Открытый опрос • Вы уже проголосовали",
    "Open poll • Click to vote" : "Открытый опрос • Нажмите, чтобы проголосовать",
    "Poll • Ended" : "Опрос • Завершён",
    "Talk recording from {time} ({conversation})" : "Голосовое сообщение записано в {time} ({conversation})",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["Результаты опроса • %n голос","Результаты опроса • %n голоса","Результаты опроса • %n голосов","Результаты опроса • %n голосов"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["Открытый опрос • %n голос","Открытый опрос • %n голоса","Открытый опрос • %n голосов","Открытый опрос • %n голосов"],
    "Submit vote" : "Проголосовать",
    "Your privacy setting has been saved" : "Параметры конфиденциальности сохранены",
    "Your personal setting has been saved" : "Персональные параметры сохранены",
    "Failed to save sounds setting" : "Не удалось сохранить настройки звуков",
    "Sounds setting saved" : "Параметры звука сохранены",
    "Always shown if recording consent is required" : "Всегда отображается, если требуется согласие на запись вызова",
    "Nextcloud Talk was updated, you cannot start or join a call." : "Nextcloud Talk был обновлен, вы не можете начать или присоединиться к вызову.",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Вы подключены к обсуждению в другом окне или устройстве. Данная возможность не поддерживается Nextcloud Talk в настоящее время, поэтому данная сессия будет закрыта.",
    "Nextcloud Talk was updated." : "Nextcloud Talk был обновлен.",
    "Nextcloud is in maintenance mode." : "Сервер находится в режиме обслуживания.",
    "Nextcloud Talk Federation was updated." : "Nextcloud Talk Федерация была обновлена.",
    "Enable live translation" : "Включить онлайн-перевод",
    "I picked list style" : "Я выбираю в стиле списка",
    "Hey! Are you using Talk in list style or with message bubbles?" : "Привет! Ты используешь чат в Конференциях в стиле списка или пузырей?"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
